@@ -35,7 +35,6 @@
 #include <gio/gio.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
-#include <gconf/gconf-client.h>
 
 #include <gdk/gdk.h>
 #include <gdk/gdkkeysyms.h>
@@ -102,6 +101,7 @@ typedef struct {
 typedef struct _TotemEmbedded {
 	GObject parent;
 
+	DBusGConnection *conn;
 	GtkWidget *window;
 	GtkBuilder *menuxml, *xml;
 	GtkWidget *about;
@@ -119,6 +119,7 @@ typedef struct _TotemEmbedded {
 	char *href_uri;
 	char *target;
 	char *stream_uri;
+	gint64 size; /* the size of the streamed file for fd://0 */
 	BaconVideoWidget *bvw;
 	TotemStates state;
 	GdkCursor *cursor;
@@ -287,6 +288,12 @@ totem_embedded_exit (TotemEmbedded *emb)
 static void
 totem_embedded_error_and_exit (char *title, char *reason, TotemEmbedded *emb)
 {
+	/* Avoid any more contacts, so drop off the bus */
+	if (emb->conn != NULL) {
+		dbus_g_connection_unregister_g_object(emb->conn, G_OBJECT (emb));
+		emb->conn = NULL;
+	}
+
 	/* FIXME send a signal to the plugin with the error message instead! */
 	totem_interface_error_blocking (title, reason,
 			GTK_WINDOW (emb->window));
@@ -365,6 +372,7 @@ totem_embedded_set_state (TotemEmbedded *emb, TotemStates state)
 				 NULL);
 		}
 		break;
+	case TOTEM_STATE_INVALID:
 	default:
 		g_assert_not_reached ();
 		break;
@@ -403,14 +411,18 @@ totem_embedded_open_internal (TotemEmbedded *emb,
 			      GError **error)
 {
 	gboolean retval;
-	const char *uri;
+	char *uri;
 
 	/* FIXME: stop previous content, or is that automatic ? */
 
-	if (emb->is_browser_stream)
-		uri = "fd://0";
-	else
-		uri = emb->current_uri;
+	if (emb->is_browser_stream) {
+		if (emb->size > 0)
+			uri = g_strdup_printf ("fd://0?size=%"G_GINT64_FORMAT, emb->size);
+		else
+			uri = g_strdup ("fd://0");
+	} else {
+		uri = g_strdup (emb->current_uri);
+	}
 
 	if (!uri) {
 		g_set_error_literal (error,
@@ -428,6 +440,8 @@ totem_embedded_open_internal (TotemEmbedded *emb,
 	bacon_video_widget_set_logo_mode (emb->bvw, FALSE);
 
 	retval = bacon_video_widget_open (emb->bvw, uri, emb->current_subtitle_uri, NULL);
+	g_free (uri);
+
 	/* FIXME we shouldn't even do that here */
 	if (start_play)
 		totem_embedded_play (emb, NULL);
@@ -748,7 +762,7 @@ totem_embedded_set_fullscreen (TotemEmbedded *emb,
 
 		totem_fullscreen_set_fullscreen (emb->fs, FALSE);
 		gtk_widget_reparent (GTK_WIDGET (emb->bvw), container);
-		gtk_widget_hide_all (emb->fs_window);
+		gtk_widget_hide (emb->fs_window);
 
 		gtk_action_set_sensitive (fs_action, TRUE);
 	} else {
@@ -781,6 +795,18 @@ totem_embedded_set_fullscreen (TotemEmbedded *emb,
 	return TRUE;
 }
 
+static gboolean
+totem_embedded_set_time (TotemEmbedded *emb,
+			 guint64 _time,
+			 GError **error)
+{
+	g_message ("totem_embedded_set_time: %"G_GUINT64_FORMAT, _time);
+
+	bacon_video_widget_seek_time (emb->bvw, _time, FALSE, NULL);
+
+	return TRUE;
+}
+
 static gboolean
 totem_embedded_open_uri (TotemEmbedded *emb,
 			 const char *uri,
@@ -800,12 +826,12 @@ totem_embedded_open_uri (TotemEmbedded *emb,
 }
 
 static gboolean
-totem_embedded_open_stream (TotemEmbedded *emb,
-			    const char *uri,
-			    const char *base_uri,
-			    GError **error)
+totem_embedded_setup_stream (TotemEmbedded *emb,
+			     const char *uri,
+			     const char *base_uri,
+			     GError **error)
 {
-	g_message ("totem_embedded_open_stream called: uri %s, base_uri: %s", uri, base_uri);
+	g_message ("totem_embedded_setup_stream called: uri %s, base_uri: %s", uri, base_uri);
 
 	totem_embedded_clear_playlist (emb, NULL);
 
@@ -816,6 +842,18 @@ totem_embedded_open_stream (TotemEmbedded *emb,
 
 	/* FIXME: consume any remaining input from stdin */
 
+	return TRUE;
+}
+
+static gboolean
+totem_embedded_open_stream (TotemEmbedded *emb,
+			    gint64 size,
+			    GError **error)
+{
+	g_message ("totem_embedded_open_stream called: with size %"G_GINT64_FORMAT, size);
+
+	emb->size = size;
+
 	return totem_embedded_open_internal (emb, TRUE, error);
 }
 
@@ -875,6 +913,7 @@ totem_embedded_open_playlist_item (TotemEmbedded *emb,
 			g_message ("Seeking to %d seconds for starttime", plitem->starttime);
 			retval = bacon_video_widget_seek_time (emb->bvw,
 							       plitem->starttime * 1000,
+							       FALSE,
 							       NULL /* FIXME */);
 			if (!retval)
 				return TRUE;
@@ -1154,7 +1193,9 @@ on_copy_location1_activate (GtkButton *button, TotemEmbedded *emb)
 	GtkClipboard *clip;
 	const char *uri;
 
-	if (emb->href_uri != NULL) {
+	if (emb->stream_uri != NULL) {
+		uri = emb->stream_uri;
+	} else if (emb->href_uri != NULL) {
 		uri = emb->href_uri;
 	} else {
 		uri = emb->current_uri;
@@ -1202,7 +1243,7 @@ popup_menu_position_func (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, Gt
 	GtkTextDirection direction;
 	GtkAllocation allocation;
 
-	gtk_widget_size_request (GTK_WIDGET (menu), &menu_req);
+	gtk_widget_get_preferred_size (GTK_WIDGET (menu), NULL, &menu_req);
 
 	direction = gtk_widget_get_direction (widget);
 
@@ -1634,6 +1675,13 @@ property_notify_cb_volume (BaconVideoWidget *bvw,
 static gboolean
 on_seek_start (GtkWidget *widget, GdkEventButton *event, TotemEmbedded *emb)
 {
+	/* HACK: we want the behaviour you get with the middle button, so we
+	 * mangle the event.  clicking with other buttons moves the slider in
+	 * step increments, clicking with the middle button moves the slider to
+	 * the location of the click.
+	 */
+	event->button = 2;
+
 	emb->seeking = TRUE;
 	totem_time_label_set_seeking (TOTEM_TIME_LABEL (emb->fs->time_label),
 				      TRUE);
@@ -1644,6 +1692,9 @@ on_seek_start (GtkWidget *widget, GdkEventButton *event, TotemEmbedded *emb)
 static gboolean
 cb_on_seek (GtkWidget *widget, GdkEventButton *event, TotemEmbedded *emb)
 {
+	/* HACK: see on_seek_start */
+	event->button = 2;
+
 	bacon_video_widget_seek (emb->bvw,
 		gtk_range_get_value (GTK_RANGE (widget)) / 65535, NULL);
 	totem_time_label_set_seeking (TOTEM_TIME_LABEL (emb->fs->time_label),
@@ -1669,7 +1720,7 @@ video_widget_size_allocate_cb (GtkWidget *controls,
 			       GtkAllocation *allocation,
 			       BaconVideoWidget *bvw)
 {
-	bacon_video_widget_set_show_visuals (bvw, allocation->height > MINIMUM_VIDEO_SIZE);
+	bacon_video_widget_set_show_visualizations (bvw, allocation->height > MINIMUM_VIDEO_SIZE);
 	g_signal_handlers_disconnect_by_func (controls, G_CALLBACK (video_widget_size_allocate_cb), NULL);
 }
 
@@ -1690,31 +1741,30 @@ static gboolean
 totem_embedded_handle_key_press (TotemEmbedded *emb, GdkEventKey *event)
 {
 	switch (event->keyval) {
-	case GDK_Escape:
+	case GDK_KEY_Escape:
 		if (totem_fullscreen_is_fullscreen (emb->fs) != FALSE)
 			totem_embedded_toggle_fullscreen (emb);
 		return TRUE;
-	case GDK_F11:
-	case GDK_f:
-	case GDK_F:
+	case GDK_KEY_F11:
+	case GDK_KEY_f:
+	case GDK_KEY_F:
 		totem_embedded_toggle_fullscreen (emb);
 		return TRUE;
-	case GDK_space:
+	case GDK_KEY_space:
 		on_play_pause (NULL, emb);
 		return TRUE;
-	case GDK_Up:
+	case GDK_KEY_Up:
 		totem_embedded_action_volume_relative (emb, VOLUME_UP_OFFSET);
 		return TRUE;
-	case GDK_Down:
+	case GDK_KEY_Down:
 		totem_embedded_action_volume_relative (emb, VOLUME_DOWN_OFFSET);
 		return TRUE;
-	case GDK_Left:
-	case GDK_Right:
+	case GDK_KEY_Left:
+	case GDK_KEY_Right:
 		/* FIXME: */
-		break;
+	default:
+		return FALSE;
 	}
-
-	return FALSE;
 }
 
 static gboolean
@@ -1727,9 +1777,11 @@ totem_embedded_key_press_event (GtkWidget *widget, GdkEventKey *event,
 	if (event->state & GDK_CONTROL_MASK)
 	{
 		switch (event->keyval) {
-		case GDK_Left:
-		case GDK_Right:
+		case GDK_KEY_Left:
+		case GDK_KEY_Right:
 			return totem_embedded_handle_key_press (emb, event);
+		default:
+			break;
 		}
 	}
 
@@ -1754,8 +1806,6 @@ totem_embedded_construct (TotemEmbedded *emb,
 	GtkWidget *menu;
 	BvwUseType type;
 	GError *err = NULL;
-	GConfClient *gc;
-	double volume;
 
 	emb->xml = totem_interface_load ("mozilla-viewer.ui", TRUE,
 					 GTK_WINDOW (emb->window), emb);
@@ -1897,27 +1947,22 @@ totem_embedded_construct (TotemEmbedded *emb,
 	g_signal_connect (G_OBJECT (popup_button), "button-press-event",
 			  G_CALLBACK (on_popup_button_button_pressed), emb);
 
-	gc = gconf_client_get_default ();
-	volume = ((double) gconf_client_get_int (gc, GCONF_PREFIX"/volume", NULL)) / 100.0;
-	g_object_unref (G_OBJECT (gc));
-
 	emb->volume = GTK_WIDGET (gtk_builder_get_object (emb->xml, "volume_button"));
 	gtk_scale_button_set_adjustment (GTK_SCALE_BUTTON (emb->fs->volume),
 					 gtk_scale_button_get_adjustment 
 					 (GTK_SCALE_BUTTON (emb->volume)));
 	gtk_button_set_focus_on_click (GTK_BUTTON (emb->volume), FALSE);
-	gtk_scale_button_set_value (GTK_SCALE_BUTTON (emb->volume), volume);
 	g_signal_connect (G_OBJECT (emb->volume), "value-changed",
 			  G_CALLBACK (cb_vol), emb);
-	bacon_video_widget_set_volume (emb->bvw, volume);
-	totem_embedded_volume_changed (emb, volume);
 
 	emb->statusbar = TOTEM_STATUSBAR (gtk_builder_get_object (emb->xml, "statusbar"));
-	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (emb->statusbar), FALSE);
 
 	if (!emb->hidden) {
 		gtk_widget_set_size_request (emb->window, width, height);
 		emb->scrsaver = totem_scrsaver_new ();
+		g_object_set (emb->scrsaver,
+			      "reason", _("Playing a movie"),
+			      NULL);
 	}
 
 #ifdef GNOME_ENABLE_DEBUG
@@ -2109,22 +2154,26 @@ totem_embedded_push_parser (gpointer data)
 	g_file_delete (file, NULL, NULL);
 	g_object_unref (file);
 
-	if (res != TOTEM_PL_PARSER_RESULT_SUCCESS) {
-		//FIXME show a proper error message
-		switch (res) {
-		case TOTEM_PL_PARSER_RESULT_UNHANDLED:
-			g_print ("url '%s' unhandled\n", emb->current_uri);
-			break;
-		case TOTEM_PL_PARSER_RESULT_ERROR:
-			g_print ("error handling url '%s'\n", emb->current_uri);
-			break;
-		case TOTEM_PL_PARSER_RESULT_IGNORED:
-			g_print ("ignored url '%s'\n", emb->current_uri);
-			break;
-		default:
-			g_assert_not_reached ();
-			;;
-		}
+	/* FIXME: show a proper error message */
+	switch (res) {
+	case TOTEM_PL_PARSER_RESULT_SUCCESS:
+		/* Success! */
+		break;
+	case TOTEM_PL_PARSER_RESULT_UNHANDLED:
+		g_print ("url '%s' unhandled\n", emb->current_uri);
+		break;
+	case TOTEM_PL_PARSER_RESULT_ERROR:
+		g_print ("error handling url '%s'\n", emb->current_uri);
+		break;
+	case TOTEM_PL_PARSER_RESULT_IGNORED:
+		g_print ("ignored url '%s'\n", emb->current_uri);
+		break;
+	case TOTEM_PL_PARSER_RESULT_CANCELLED:
+		g_print ("cancelled url '%s'\n", emb->current_uri);
+		break;
+	default:
+		g_assert_not_reached ();
+		;;
 	}
 
 	/* Check if we have anything in the playlist now */
@@ -2249,7 +2298,7 @@ int main (int argc, char **argv)
 
 		env = g_getenv ("TOTEM_EMBEDDED_GDB");
 		if (env && g_ascii_strtoull (env, NULL, 10) == 1) {
-			char *gdbargv[4];
+			const char *gdbargv[4];
 			char *gdb;
 			GError *gdberr = NULL;
 			int gdbargc = 0;
@@ -2262,7 +2311,7 @@ int main (int argc, char **argv)
 			gdbargv[gdbargc++] = NULL;
 
 			if (!g_spawn_async (NULL,
-					    gdbargv,
+					    (gchar**) gdbargv,
 					    NULL /* env */,
 					    0,
 					    NULL, NULL,
@@ -2274,6 +2323,8 @@ int main (int argc, char **argv)
 				g_print ("Sleeping....\n");
 				g_usleep (10* 1000 * 1000); /* 10s */
 			}
+
+			g_free (gdb);
 		}
 	}
 #endif
@@ -2347,8 +2398,10 @@ int main (int argc, char **argv)
         emb->referrer_uri = arg_referrer;
 
 	/* FIXME: register this BEFORE requesting the service name? */
-	dbus_g_connection_register_g_object
-	(conn, TOTEM_PLUGIN_VIEWER_DBUS_PATH, G_OBJECT (emb));
+	dbus_g_connection_register_g_object (conn,
+					     TOTEM_PLUGIN_VIEWER_DBUS_PATH,
+					     G_OBJECT (emb));
+	emb->conn = conn;
 
 	/* If we're hidden, construct a hidden window;
 	 * else wait to be plugged in.
