@@ -31,11 +31,14 @@ TODO:
 """
 
 import os
-import totem
-import gconf
 import gobject
-import gtk
-import pango
+from gi.repository import Gio
+from gi.repository import Peas
+from gi.repository import PeasGtk
+from gi.repository import Gtk
+from gi.repository import GdkPixbuf
+from gi.repository import Totem
+from gi.repository import Pango
 import socket
 import threading
 import time
@@ -48,9 +51,9 @@ except ImportError:
     try:
         import simplejson as json
     except ImportError:
-        dlg = gtk.MessageDialog(
-            type=gtk.MESSAGE_ERROR,
-            buttons=gtk.BUTTONS_OK
+        dlg = Gtk.MessageDialog(
+            message_type=Gtk.MessageType.ERROR,
+            buttons=Gtk.ButtonsType.OK
         )
         dlg.set_markup(_('You need to install the Python simplejson module.'))
         dlg.run()
@@ -59,10 +62,12 @@ except ImportError:
 
 socket.setdefaulttimeout(30)
 gobject.threads_init()
-gconf_key = '/apps/totem/plugins/jamendo'
 
+class JamendoPlugin(gobject.GObject, Peas.Activatable, PeasGtk.Configurable):
+    __gtype_name__ = 'JamendoPlugin'
+
+    object = gobject.property(type = gobject.GObject)
 
-class JamendoPlugin(totem.Plugin):
     """
     Jamendo totem plugin GUI.
     """
@@ -73,76 +78,94 @@ class JamendoPlugin(totem.Plugin):
     TAB_LATEST      = 2
 
     def __init__(self):
-        totem.Plugin.__init__(self)
         self.debug = True
         self.gstreamer_plugins_present = True
-        self.totem = None
-        self.gconf = gconf.client_get_default()
-        self.init_settings()
+        self.totem = self.object
+        self.settings = Gio.Settings.new ('org.gnome.totem.plugins.jamendo')
+        self.settings.connect ('changed::format', self.on_format_changed)
+        self.settings.connect ('changed::num-per-page', self.on_num_per_page_changed)
 
-    def activate(self, totem_object):
+    def do_activate(self):
         """
         Plugin activation.
         """
         # Initialise the interface
-        self.builder = self.load_interface("jamendo.ui", True,
-            totem_object.get_main_window(), self)
-        self.config_dialog = self.builder.get_object('config_dialog')
-        self.popup = self.builder.get_object('popup_menu')
-        container = self.builder.get_object('container')
-        self.notebook = self.builder.get_object('notebook')
-        self.search_entry = self.builder.get_object('search_entry')
-        self.search_combo = self.builder.get_object('search_combo')
+        builder = Totem.plugin_load_interface ("jamendo", "jamendo.ui", True, self.totem.get_main_window (), self)
+        self.popup = builder.get_object('popup_menu')
+        container = builder.get_object('container')
+        self.notebook = builder.get_object('notebook')
+        self.search_entry = builder.get_object('search_entry')
+        self.search_combo = builder.get_object('search_combo')
         self.search_combo.set_active(0)
-        self.album_button = self.builder.get_object('album_button')
-        self.previous_button = self.builder.get_object('previous_button')
-        self.next_button = self.builder.get_object('next_button')
+        self.album_button = builder.get_object('album_button')
+        self.previous_button = builder.get_object('previous_button')
+        self.next_button = builder.get_object('next_button')
         self.progressbars = [
-            self.builder.get_object('results_progressbar'),
-            self.builder.get_object('popular_progressbar'),
-            self.builder.get_object('latest_progressbar'),
+            builder.get_object('results_progressbar'),
+            builder.get_object('popular_progressbar'),
+            builder.get_object('latest_progressbar'),
         ]
         self.treeviews = [
-            self.builder.get_object('results_treeview'),
-            self.builder.get_object('popular_treeview'),
-            self.builder.get_object('latest_treeview'),
+            builder.get_object('results_treeview'),
+            builder.get_object('popular_treeview'),
+            builder.get_object('latest_treeview'),
         ]
         self.setup_treeviews()
 
         # Set up signals
-        self.builder.get_object('search_button').connect('clicked', self.on_search_button_clicked)
+        builder.get_object('search_button').connect('clicked', self.on_search_button_clicked)
         self.search_entry.connect('activate', self.on_search_entry_activate)
         self.notebook.connect('switch-page', self.on_notebook_switch_page)
         self.previous_button.connect('clicked', self.on_previous_button_clicked)
         self.next_button.connect('clicked', self.on_next_button_clicked)
         self.album_button.connect('clicked', self.on_album_button_clicked)
-        self.builder.get_object('cancel_button').connect('clicked', self.on_cancel_button_clicked)
-        self.builder.get_object('ok_button').connect('clicked', self.on_ok_button_clicked)
-        self.builder.get_object('add_to_playlist').connect('activate', self.on_add_to_playlist_activate)
-        self.builder.get_object('jamendo_album_page').connect('activate', self.on_open_jamendo_album_page_activate)
+        builder.get_object('add_to_playlist').connect('activate', self.on_add_to_playlist_activate)
+        builder.get_object('jamendo_album_page').connect('activate', self.on_open_jamendo_album_page_activate)
 
-        self.totem = totem_object
         self.reset()
         container.show_all()
         self.totem.add_sidebar_page("jamendo", _("Jamendo"), container)
 
-    def deactivate(self, totem_object):
+    def do_deactivate(self):
         """
         Plugin deactivation.
         """
-        totem_object.remove_sidebar_page("jamendo")
+        self.totem.remove_sidebar_page("jamendo")
 
-    def create_configure_dialog(self, *args):
+    def do_create_configure_widget(self):
         """
-        Plugin config dialog.
+        Plugin config widget.
+        This code must be independent from the rest of the plugin. FIXME: bgo#624073
         """
-        format = self.gconf.get_string('%s/format' % gconf_key)
-        num_per_page = self.gconf.get_int('%s/num_per_page' % gconf_key)
-        combo = self.builder.get_object('preferred_format_combo')
-        combo.set_active(self.AUDIO_FORMATS.index(format))
-        spinbutton = self.builder.get_object('album_num_spinbutton')
+        builder = Totem.plugin_load_interface ('jamendo', 'jamendo.ui', True, None, self)
+        print builder
+        config_widget = builder.get_object ('config_widget')
+        config_widget.connect ('destroy', self.on_config_widget_destroy)
+        print config_widget
+        format = self.settings.get_enum ('format')
+        num_per_page = self.settings.get_int ('num-per-page')
+
+        combo = builder.get_object('preferred_format_combo')
+        combo.set_active(format)
+        self.settings.bind ('format', combo, 'active', Gio.SettingsBindFlags.DEFAULT)
+
+        spinbutton = builder.get_object('album_num_spinbutton')
         spinbutton.set_value(num_per_page)
-        return self.config_dialog
+        self.settings.bind ('num-per-page', spinbutton, 'value', Gio.SettingsBindFlags.DEFAULT)
+
+        return config_widget
+
+    def on_format_changed (self, settings, key):
+        JamendoService.AUDIO_FORMAT = self.settings.get_enum ('format')
+
+    def on_num_per_page_changed (self, settings, key):
+        JamendoService.NUM_PER_PAGE = self.settings.get_int ('num-per-page')
+
+    def on_config_widget_destroy (self, widget):
+        try:
+            self.reset()
+        except:
+            pass
 
     def reset(self):
         """
@@ -168,54 +191,33 @@ class JamendoPlugin(totem.Plugin):
             tv.get_model().clear()
         self._update_buttons_state()
 
-    def init_settings(self):
-        """
-        Initialize plugin settings.
-        """
-        format = self.gconf.get_string('%s/format' % gconf_key)
-        if not format:
-            format = 'ogg2'
-            self.gconf.set_string('%s/format' % gconf_key, format)
-        num_per_page = self.gconf.get_int('%s/num_per_page' % gconf_key)
-        if not num_per_page:
-            num_per_page = 10
-            self.gconf.set_int('%s/num_per_page' % gconf_key, num_per_page)
-        JamendoService.AUDIO_FORMAT = format
-        JamendoService.NUM_PER_PAGE = num_per_page
-
     def setup_treeviews(self):
         """
         Setup the 3 treeview: result, popular and latest
         """
         self.current_treeview = self.treeviews[0]
         for w in self.treeviews:
-            w.get_selection().set_mode(gtk.SELECTION_MULTIPLE)
+            w.get_selection().set_mode(Gtk.SelectionMode.MULTIPLE)
 
             # build pixbuf column
-            cell = gtk.CellRendererPixbuf()
-            col = gtk.TreeViewColumn()
-            col.pack_start(cell, True)
-            col.set_attributes(cell, pixbuf=1)
+            cell = Gtk.CellRendererPixbuf()
+            col = Gtk.TreeViewColumn(cell_renderer=cell, pixbuf=1)
+
             w.append_column(col)
 
             # build description column
-            cell = gtk.CellRendererText()
-            cell.set_property('wrap-mode', pango.WRAP_WORD)
+            cell = Gtk.CellRendererText()
+            cell.set_property('wrap-mode', Pango.WrapMode.WORD)
             cell.set_property('wrap-width', 30)
-            col = gtk.TreeViewColumn()
-            col.pack_start(cell, True)
-            col.set_attributes(cell, markup=2)
+            col = Gtk.TreeViewColumn(cell_renderer=cell, markup=2)
             col.set_expand(True)
             w.append_column(col)
-            w.connect_after('size-allocate', self.on_treeview_size_allocate, col, cell)
 
             # duration column
-            cell = gtk.CellRendererText()
+            cell = Gtk.CellRendererText()
             cell.set_property('xalign', 1.0)
             cell.set_property('size-points', 8)
-            col = gtk.TreeViewColumn()
-            col.pack_start(cell, True)
-            col.set_attributes(cell, markup=3)
+            col = Gtk.TreeViewColumn(cell_renderer=cell, markup=3)
             col.set_alignment(1.0)
             w.append_column(col)
 
@@ -229,15 +231,15 @@ class JamendoPlugin(totem.Plugin):
 
 
     def add_treeview_item(self, treeview, album):
-        if not isinstance(album['image'], gtk.gdk.Pixbuf):
+        if not isinstance(album['image'], GdkPixbuf.Pixbuf):
             # album image pixbuf is not yet built
             try:
-                pb = gtk.gdk.pixbuf_new_from_file(album['image'])
+                pb = GdkPixbuf.Pixbuf.new_from_file(album['image'])
                 os.unlink(album['image'])
                 album['image'] = pb
             except:
                 # do not fail for this, just display a dummy pixbuf
-                album['image'] = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, True,
+                album['image'] = GdkPixbuf.Pixbuf.new(GdkPixbuf.Colorspace.RGB, True,
                     8, 1, 1)
         # format title
         title  = '<b>%s</b>\n' % self._format_str(album['name'])
@@ -263,8 +265,9 @@ class JamendoPlugin(totem.Plugin):
         parent = treeview.get_model().append(None,
             [album, album['image'], title, dur, tip]
         )
+
         # append track rows
-        icon = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, True, 8, 1, 1)
+        icon = GdkPixbuf.Pixbuf.new(GdkPixbuf.Colorspace.RGB, True, 8, 1, 1)
         for i, track in enumerate(album['tracks']):
             # track title
             # Translators: this is the title of a track in Python format
@@ -308,9 +311,9 @@ class JamendoPlugin(totem.Plugin):
         enqueue_and_play.
         """
         if mode == 'replace':
-            self.totem.action_remote(totem.REMOTE_COMMAND_REPLACE, t['stream'])
+            self.totem.action_remote(Totem.RemoteCommand.REPLACE, t['stream'])
         elif mode == 'enqueue':
-            self.totem.action_remote(totem.REMOTE_COMMAND_ENQUEUE, t['stream'])
+            self.totem.action_remote(Totem.RemoteCommand.ENQUEUE, t['stream'])
 
     def fetch_albums(self, pn=1):
         """
@@ -379,13 +382,7 @@ class JamendoPlugin(totem.Plugin):
         self.progressbars[pindex].set_fraction(0.0)
         self.progressbars[pindex].hide()
         self.running_threads[pindex] = False
-        dlg = gtk.MessageDialog(
-            type=gtk.MESSAGE_ERROR,
-            buttons=gtk.BUTTONS_OK
-        )
-        dlg.set_markup(
-            '<b>%s</b>' % _('An error occurred while fetching albums.')
-        )
+
         # managing exceptions with urllib is a real PITA... :(
         if hasattr(exc, 'reason'):
             try:
@@ -401,9 +398,8 @@ class JamendoPlugin(totem.Plugin):
             msg = _('The Jamendo server returned code %s.') % exc.code
         else:
             msg = str(exc)
-        dlg.format_secondary_text(msg)
-        dlg.run()
-        dlg.destroy()
+
+        self.totem.action_error(_('An error occurred while fetching albums.'), msg)
 
     def on_search_entry_activate(self, *args):
         """
@@ -464,16 +460,16 @@ class JamendoPlugin(totem.Plugin):
             if evt.button == 3:
                 path = tv.get_path_at_pos(int(evt.x), int(evt.y))
                 sel  = tv.get_selection()
-                rows = sel.get_selected_rows()
-                if path[0] not in rows[1]:
+                (rows, _) = sel.get_selected_rows()
+                if path[1] not in rows[1]:
                     sel.unselect_all()
-                    sel.select_path(path[0])
+                    sel.select_path(path[1])
                 tv.grab_focus()
                 self.popup.popup(None, None, None, evt.button, evt.time)
                 return True
             coords = evt.get_coords()
-            path, c, x, y = tv.get_path_at_pos(int(coords[0]), int(coords[1]))
-            if (len(path) == 1):
+            _, path, c, x, y = tv.get_path_at_pos(int(coords[0]), int(coords[1]))
+            if (path.get_depth() == 1):
                 if tv.row_expanded(path):
                     tv.collapse_row(path)
                 else:
@@ -482,16 +478,6 @@ class JamendoPlugin(totem.Plugin):
         except:
             pass
 
-    def on_treeview_size_allocate(self, tv, allocation, col, cell):
-        """
-        Hack to autowrap text of the title colum.
-        """
-        cols = (c for c in tv.get_columns() if c != col)
-        w = allocation.width - sum(c.get_width() for c in cols)
-        if cell.props.wrap_width == w or w <= 0:
-            return
-        cell.props.wrap_width = w
-
     def on_previous_button_clicked(self, *args):
         """
         Called when the user clicked the previous button.
@@ -533,29 +519,6 @@ class JamendoPlugin(totem.Plugin):
         except:
             pass
 
-    def on_cancel_button_clicked(self, *args):
-        """
-        Called when the user clicked cancel in the config dialog.
-        """
-        self.config_dialog.hide()
-
-    def on_ok_button_clicked(self, *args):
-        """
-        Called when the user clicked ok in the config dialog.
-        """
-        combo = self.builder.get_object('preferred_format_combo')
-        spinbutton = self.builder.get_object('album_num_spinbutton')
-        format = self.AUDIO_FORMATS[combo.get_active()]
-        self.gconf.set_string('%s/format' % gconf_key, format)
-        num_per_page = int(spinbutton.get_value())
-        self.gconf.set_int('%s/num_per_page' % gconf_key, num_per_page)
-        self.init_settings()
-        self.config_dialog.hide()
-        try:
-            self.reset()
-        except:
-            pass
-
     def on_add_to_playlist_activate(self, *args):
         """
         Called when the user clicked on the add to playlist button of the
@@ -583,7 +546,7 @@ class JamendoPlugin(totem.Plugin):
         """
         ret = []
         sel = self.current_treeview.get_selection()
-        model, rows = sel.get_selected_rows()
+        (rows, model) = sel.get_selected_rows()
         for row in rows:
             if root:
                 it = model.get_iter((row[0],))
@@ -599,7 +562,7 @@ class JamendoPlugin(totem.Plugin):
         Update the state of the previous and next buttons.
         """
         sel = self.current_treeview.get_selection()
-        model, rows = sel.get_selected_rows()
+        (rows, model) = sel.get_selected_rows()
         try:
             it = model.get_iter(rows[0])
         except:
@@ -670,7 +633,7 @@ class JamendoService(threading.Thread):
                 album['image'] = fname
                 album['tracks'] = json.loads(self._request(
                     '%s/id+name+duration+stream/track/json/?album_id=%s'\
-                    '&order=numalbum_asc' % (self.API_URL, album['id'])
+                    '&order=numalbum_asc&streamencoding=%s' % (self.API_URL, album['id'], self.AUDIO_FORMAT)
                 ))
                 album['license'] = json.loads(self._request(
                     '%s/name/license/json/album_license/?album_id=%s'\
@@ -686,7 +649,7 @@ class JamendoService(threading.Thread):
                 album['url'] = album['url'].replace('/en/', '/' + _('en') + '/')
                 gobject.idle_add(self.loop_cb[0], self.loop_cb[1], album)
             gobject.idle_add(self.done_cb[0], self.done_cb[1], albums)
-        except Exception, exc:
+        except Exception as exc:
             gobject.idle_add(self.error_cb[0], self.error_cb[1], exc)
         finally:
             self.lock.release()
@@ -698,4 +661,3 @@ class JamendoService(threading.Thread):
         data = handle.read()
         handle.close()
         return data
-
