@@ -32,7 +32,6 @@
 
 #include <glib-object.h>
 #include <glib/gi18n-lib.h>
-#include <gconf/gconf-client.h>
 #include <gio/gio.h>
 
 #include <libepc/consumer.h>
@@ -44,7 +43,7 @@
 #include <libpeas/peas-extension-base.h>
 #include <libpeas/peas-object-module.h>
 #include <libpeas/peas-activatable.h>
-#include <libpeasui/peas-ui-configurable.h>
+#include <libpeas-gtk/peas-gtk-configurable.h>
 
 #include "ev-sidebar.h"
 #include "totem-plugin.h"
@@ -59,9 +58,7 @@
 #define TOTEM_IS_PUBLISH_PLUGIN_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), TOTEM_TYPE_PUBLISH_PLUGIN))
 #define TOTEM_PUBLISH_PLUGIN_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), TOTEM_TYPE_PUBLISH_PLUGIN, TotemPublishPluginClass))
 
-#define TOTEM_PUBLISH_CONFIG_ROOT		GCONF_PREFIX "/plugins/publish"
-#define TOTEM_PUBLISH_CONFIG_NAME		GCONF_PREFIX "/plugins/publish/name"
-#define TOTEM_PUBLISH_CONFIG_PROTOCOL		GCONF_PREFIX "/plugins/publish/protocol"
+#define TOTEM_PUBLISH_SCHEMA			TOTEM_GSETTINGS_SCHEMA ".plugins.publish"
 
 enum
 {
@@ -70,12 +67,9 @@ enum
 	LAST_COLUMN
 };
 
-typedef struct
-{
-	PeasExtensionBase parent;
-
+typedef struct {
 	TotemObject       *totem;
-	GConfClient       *client;
+	GSettings         *gsettings;
 	GtkWidget         *settings;
 	GtkWidget         *scanning;
 	GtkBuilder        *ui;
@@ -85,26 +79,18 @@ typedef struct
 	GtkListStore      *neighbours;
 	GSList            *playlist;
 
-	guint name_id;
-	guint protocol_id;
-
 	guint scanning_id;
 
 	gulong item_added_id;
 	gulong item_removed_id;
-} TotemPublishPlugin;
+} TotemPublishPluginPrivate;
 
-typedef struct
-{
-	PeasExtensionBaseClass parent_class;
-} TotemPublishPluginClass;
-
-GType totem_publish_plugin_get_type (void) G_GNUC_CONST;
+TOTEM_PLUGIN_REGISTER_CONFIGURABLE (TOTEM_TYPE_PUBLISH_PLUGIN, TotemPublishPlugin, totem_publish_plugin);
 
 void totem_publish_plugin_service_name_entry_changed_cb	   (GtkEntry        *entry,
-							    gpointer         data);
+							    TotemPublishPlugin *self);
 void totem_publish_plugin_encryption_button_toggled_cb	   (GtkToggleButton *button,
-							    gpointer         data);
+							    TotemPublishPlugin *self);
 void totem_publish_plugin_dialog_response_cb		   (GtkDialog       *dialog,
 							    gint             response,
 							    gpointer         data);
@@ -114,67 +100,47 @@ void totem_publish_plugin_neighbours_list_row_activated_cb (GtkTreeView       *v
 							    gpointer           data);
 
 G_LOCK_DEFINE_STATIC(totem_publish_plugin_lock);
-TOTEM_PLUGIN_REGISTER_CONFIGURABLE (TOTEM_TYPE_PUBLISH_PLUGIN, TotemPublishPlugin, totem_publish_plugin);
 
 static void
-totem_publish_plugin_name_changed_cb (GConfClient *client,
-				      guint        id,
-				      GConfEntry  *entry,
-				      gpointer     data)
+totem_publish_plugin_name_changed_cb (GSettings *settings, const gchar *key, TotemPublishPlugin *self)
 {
-	TotemPublishPlugin *self = TOTEM_PUBLISH_PLUGIN (data);
-	const gchar *pattern = gconf_value_get_string (entry->value);
-	gchar *name = epc_publisher_expand_name (pattern, NULL);
+	gchar *pattern, *name;
 
-	epc_publisher_set_service_name (self->publisher, name);
+	pattern = g_settings_get_string (settings, "name-format");
+	name = epc_publisher_expand_name (pattern, NULL);
+	g_free (pattern);
+
+	epc_publisher_set_service_name (self->priv->publisher, name);
 
 	g_free (name);
 }
 
 void
-totem_publish_plugin_service_name_entry_changed_cb (GtkEntry *entry,
-						    gpointer  data)
+totem_publish_plugin_service_name_entry_changed_cb (GtkEntry *entry, TotemPublishPlugin *self)
 {
-	GConfClient *client = gconf_client_get_default ();
-	gconf_client_set_string (client,
-				 TOTEM_PUBLISH_CONFIG_NAME,
-				 gtk_entry_get_text (entry),
-				 NULL);
-	g_object_unref (client);
+	g_settings_set_string (self->priv->gsettings, "name-format", gtk_entry_get_text (entry));
 }
 
 void
-totem_publish_plugin_encryption_button_toggled_cb (GtkToggleButton *button,
-						   gpointer         data)
+totem_publish_plugin_encryption_button_toggled_cb (GtkToggleButton *button, TotemPublishPlugin *self)
 {
-	GConfClient *client;
-	gboolean encryption = gtk_toggle_button_get_active (button);
-
-	client = gconf_client_get_default ();
-	gconf_client_set_string (client,
-				 TOTEM_PUBLISH_CONFIG_PROTOCOL,
-				 encryption ? "https" : "http",
-				 NULL);
-	g_object_unref (client);
+	g_settings_set_string (self->priv->gsettings, "protocol", gtk_toggle_button_get_active (button) ? "https" : "http");
 }
 
 static void
-totem_publish_plugin_protocol_changed_cb (GConfClient *client,
-					  guint        id,
-					  GConfEntry  *entry,
-					  gpointer     data)
+totem_publish_plugin_protocol_changed_cb (GSettings *settings, const gchar *key, TotemPublishPlugin *self)
 {
-	TotemPublishPlugin *self = TOTEM_PUBLISH_PLUGIN (data);
-	const gchar *protocol_name;
+	gchar *protocol_name;
 	EpcProtocol protocol;
 	GError *error = NULL;
 
-	protocol_name = gconf_value_get_string (entry->value);
+	protocol_name = g_settings_get_string (settings, "protocol");
 	protocol = epc_protocol_from_name (protocol_name, EPC_PROTOCOL_HTTPS);
+	g_free (protocol_name);
 
-	epc_publisher_quit (self->publisher);
-	epc_publisher_set_protocol (self->publisher, protocol);
-	epc_publisher_run_async (self->publisher, &error);
+	epc_publisher_quit (self->priv->publisher);
+	epc_publisher_set_protocol (self->priv->publisher, protocol);
+	epc_publisher_run_async (self->priv->publisher, &error);
 
 	if (error) {
 		g_warning ("%s: %s", G_STRFUNC, error->message);
@@ -203,9 +169,9 @@ totem_publish_plugin_playlist_cb (EpcPublisher *publisher,
 
 	g_string_append_printf (buffer,
 				"[playlist]\nNumberOfEntries=%d\n",
-				g_slist_length (self->playlist));
+				g_slist_length (self->priv->playlist));
 
-	for (iter = self->playlist, i = 1; iter; iter = iter->next, ++i) {
+	for (iter = self->priv->playlist, i = 1; iter; iter = iter->next, ++i) {
 		gchar *file_key = iter->data;
 		gchar *uri;
 
@@ -289,7 +255,7 @@ totem_publish_plugin_rebuild_playlist_cb (TotemPlaylist *playlist,
 {
 	TotemPublishPlugin *self = TOTEM_PUBLISH_PLUGIN (data);
 	gchar *key = totem_publish_plugin_build_key (filename);
-	self->playlist = g_slist_prepend (self->playlist, key);
+	self->priv->playlist = g_slist_prepend (self->priv->playlist, key);
 }
 
 static void
@@ -300,15 +266,15 @@ totem_publish_plugin_playlist_changed_cb (TotemPlaylist *playlist,
 
 	G_LOCK (totem_publish_plugin_lock);
 
-	g_slist_foreach (self->playlist, (GFunc) g_free, NULL);
-	g_slist_free (self->playlist);
-	self->playlist = NULL;
+	g_slist_foreach (self->priv->playlist, (GFunc) g_free, NULL);
+	g_slist_free (self->priv->playlist);
+	self->priv->playlist = NULL;
 
 	totem_playlist_foreach (playlist,
 				totem_publish_plugin_rebuild_playlist_cb,
 				self);
 
-	self->playlist = g_slist_reverse (self->playlist);
+	self->priv->playlist = g_slist_reverse (self->priv->playlist);
 
 	G_UNLOCK (totem_publish_plugin_lock);
 }
@@ -322,7 +288,7 @@ totem_publish_plugin_playlist_item_added_cb (TotemPlaylist *playlist,
 	TotemPublishPlugin *self = TOTEM_PUBLISH_PLUGIN (data);
 	gchar *key = totem_publish_plugin_build_key (filename);
 
-	epc_publisher_add_handler (self->publisher, key,
+	epc_publisher_add_handler (self->priv->publisher, key,
 				   totem_publish_plugin_media_cb,
 				   g_strdup (url), g_free);
 
@@ -338,7 +304,7 @@ totem_publish_plugin_playlist_item_removed_cb (TotemPlaylist *playlist,
 {
 	TotemPublishPlugin *self = TOTEM_PUBLISH_PLUGIN (data);
 	gchar *key = totem_publish_plugin_build_key (filename);
-	epc_publisher_remove (self->publisher, key);
+	epc_publisher_remove (self->priv->publisher, key);
 	g_free (key);
 }
 
@@ -349,8 +315,8 @@ totem_publish_plugin_service_found_cb (TotemPublishPlugin *self,
 {
 	GtkTreeIter iter;
 
-	gtk_list_store_append (self->neighbours, &iter);
-	gtk_list_store_set (self->neighbours, &iter, NAME_COLUMN, name,
+	gtk_list_store_append (self->priv->neighbours, &iter);
+	gtk_list_store_set (self->priv->neighbours, &iter, NAME_COLUMN, name,
 						     INFO_COLUMN, info,
 						     -1);
 }
@@ -360,7 +326,7 @@ totem_publish_plugin_service_removed_cb (TotemPublishPlugin *self,
 					 const gchar        *name,
 					 const gchar        *type)
 {
-	GtkTreeModel *model = GTK_TREE_MODEL (self->neighbours);
+	GtkTreeModel *model = GTK_TREE_MODEL (self->priv->neighbours);
 	GtkTreeIter iter;
 
 	if (gtk_tree_model_get_iter_first (model, &iter)) {
@@ -381,7 +347,7 @@ totem_publish_plugin_service_removed_cb (TotemPublishPlugin *self,
 			path = path_iter->data;
 
 			if (gtk_tree_model_get_iter (model, &iter, path))
-				gtk_list_store_remove (self->neighbours, &iter);
+				gtk_list_store_remove (self->priv->neighbours, &iter);
 
 			gtk_tree_path_free (path);
 		}
@@ -394,13 +360,13 @@ static void
 totem_publish_plugin_scanning_done_cb (TotemPublishPlugin *self,
 				       const gchar        *type)
 {
-	if (self->scanning_id) {
-		g_source_remove (self->scanning_id);
-		self->scanning_id = 0;
+	if (self->priv->scanning_id) {
+		g_source_remove (self->priv->scanning_id);
+		self->priv->scanning_id = 0;
 	}
 
-	if (self->scanning)
-		gtk_widget_hide (self->scanning);
+	if (self->priv->scanning)
+		gtk_widget_hide (self->priv->scanning);
 }
 
 static void
@@ -424,22 +390,22 @@ totem_publish_plugin_load_playlist (TotemPublishPlugin   *self,
 		if (error)
 			goto out;
 
-		ev_sidebar_set_current_page (EV_SIDEBAR (self->totem->sidebar), "playlist");
-		totem_playlist_clear (self->totem->playlist);
+		ev_sidebar_set_current_page (EV_SIDEBAR (self->priv->totem->sidebar), "playlist");
+		totem_playlist_clear (self->priv->totem->playlist);
 
-		for (i = 1; i <= n_entries; ++i) {
+		for (i = 0; i < n_entries; ++i) {
 			gchar *key, *mrl, *title;
 
-			key = g_strdup_printf ("File%d", i);
+			key = g_strdup_printf ("File%d", i + 1);
 			mrl = g_key_file_get_string (keyfile, "playlist", key, NULL);
 			g_free (key);
 
-			key = g_strdup_printf ("Title%d", i);
+			key = g_strdup_printf ("Title%d", i + 1);
 			title = g_key_file_get_string (keyfile, "playlist", key, NULL);
 			g_free (key);
 
 			if (mrl)
-				totem_playlist_add_mrl (self->totem->playlist, mrl, title, FALSE, NULL, NULL, NULL);
+				totem_playlist_add_mrl (self->priv->totem->playlist, mrl, title, FALSE, NULL, NULL, NULL);
 
 			g_free (title);
 			g_free (mrl);
@@ -468,8 +434,8 @@ totem_publish_plugin_neighbours_list_row_activated_cb (GtkTreeView       *view,
 	EpcServiceInfo *info = NULL;
 	GtkTreeIter iter;
 
-	if (gtk_tree_model_get_iter (GTK_TREE_MODEL (self->neighbours), &iter, path)) {
-		gtk_tree_model_get (GTK_TREE_MODEL (self->neighbours),
+	if (gtk_tree_model_get_iter (GTK_TREE_MODEL (self->priv->neighbours), &iter, path)) {
+		gtk_tree_model_get (GTK_TREE_MODEL (self->priv->neighbours),
 				    &iter, INFO_COLUMN, &info, -1);
 		totem_publish_plugin_load_playlist (self, info);
 		epc_service_info_unref (info);
@@ -491,23 +457,23 @@ totem_publish_plugin_create_neigbours_page (TotemPublishPlugin *self, GtkBuilder
 	page = GTK_WIDGET (gtk_builder_get_object (builder, "neighbours-page"));
 	list = GTK_WIDGET (gtk_builder_get_object (builder, "neighbours-list"));
 
-	self->scanning = GTK_WIDGET (gtk_builder_get_object (builder, "neighbours-scanning"));
-	self->scanning_id = g_timeout_add (100, totem_publish_plugin_scanning_cb, self->scanning);
+	self->priv->scanning = GTK_WIDGET (gtk_builder_get_object (builder, "neighbours-scanning"));
+	self->priv->scanning_id = g_timeout_add (100, totem_publish_plugin_scanning_cb, self->priv->scanning);
 
-	g_signal_connect_swapped (self->monitor, "service-found",
+	g_signal_connect_swapped (self->priv->monitor, "service-found",
 				  G_CALLBACK (totem_publish_plugin_service_found_cb),
 				  self);
-	g_signal_connect_swapped (self->monitor, "service-removed",
+	g_signal_connect_swapped (self->priv->monitor, "service-removed",
 				  G_CALLBACK (totem_publish_plugin_service_removed_cb),
 				  self);
-	g_signal_connect_swapped (self->monitor, "scanning-done",
+	g_signal_connect_swapped (self->priv->monitor, "scanning-done",
 				  G_CALLBACK (totem_publish_plugin_scanning_done_cb),
 				  self);
 
-	self->neighbours = gtk_list_store_new (LAST_COLUMN, G_TYPE_STRING, EPC_TYPE_SERVICE_INFO);
+	self->priv->neighbours = gtk_list_store_new (LAST_COLUMN, G_TYPE_STRING, EPC_TYPE_SERVICE_INFO);
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (list),
-				 GTK_TREE_MODEL (self->neighbours));
+				 GTK_TREE_MODEL (self->priv->neighbours));
 
 	gtk_tree_view_append_column (GTK_TREE_VIEW (list),
 		gtk_tree_view_column_new_with_attributes (
@@ -521,10 +487,10 @@ totem_publish_plugin_create_neigbours_page (TotemPublishPlugin *self, GtkBuilder
 }
 
 static void
-impl_activate (PeasActivatable *plugin, GObject *object)
+impl_activate (PeasActivatable *plugin)
 {
 	TotemPublishPlugin *self = TOTEM_PUBLISH_PLUGIN (plugin);
-	TotemObject *totem = TOTEM_OBJECT (object);
+	TotemPublishPluginPrivate *priv = self->priv;
 	EpcProtocol protocol = EPC_PROTOCOL_HTTPS;
 	GtkWindow *window;
 	GtkBuilder *builder;
@@ -535,48 +501,35 @@ impl_activate (PeasActivatable *plugin, GObject *object)
 	gchar *service_pattern;
 	gchar *service_name;
 
-	g_return_if_fail (NULL == self->publisher);
-	g_return_if_fail (NULL == self->totem);
+	g_return_if_fail (NULL == priv->publisher);
+	g_return_if_fail (NULL == priv->totem);
 
 	G_LOCK (totem_publish_plugin_lock);
 
-	self->totem = g_object_ref (totem);
+	priv->totem = g_object_ref (g_object_get_data (G_OBJECT (plugin), "object"));
 
-	window = totem_get_main_window (self->totem);
+	window = totem_get_main_window (priv->totem);
 	builder = totem_plugin_load_interface ("publish", "publish-plugin.ui", TRUE, window, self);
 	epc_progress_window_install (window);
 	g_object_unref (window);
 
-	gconf_client_add_dir (self->client,
-			      TOTEM_PUBLISH_CONFIG_ROOT,
-			      GCONF_CLIENT_PRELOAD_ONELEVEL,
-			      NULL);
+	priv->gsettings = g_settings_new (TOTEM_PUBLISH_SCHEMA);
 
-	protocol_name = gconf_client_get_string (self->client, TOTEM_PUBLISH_CONFIG_PROTOCOL, NULL);
-	service_pattern = gconf_client_get_string (self->client, TOTEM_PUBLISH_CONFIG_NAME, NULL);
+	protocol_name = g_settings_get_string (priv->gsettings, "protocol");
+	service_pattern = g_settings_get_string (priv->gsettings, "name-format");
 
-	if (!protocol_name) {
+	if (*protocol_name == '\0') {
 		protocol_name = g_strdup ("http");
-		gconf_client_set_string (self->client,
-					 TOTEM_PUBLISH_CONFIG_PROTOCOL,
-					 protocol_name, NULL);
+		g_settings_set_string (priv->gsettings, "protocol", protocol_name);
 	}
 
-	if (!service_pattern) {
+	if (*service_pattern == '\0') {
 		service_pattern = g_strdup ("%a of %u on %h");
-		gconf_client_set_string (self->client,
-					 TOTEM_PUBLISH_CONFIG_NAME,
-					 service_pattern, NULL);
+		g_settings_set_string (priv->gsettings, "name-format", service_pattern);
 	}
 
-	self->name_id = gconf_client_notify_add (self->client,
-						 TOTEM_PUBLISH_CONFIG_NAME,
-						 totem_publish_plugin_name_changed_cb,
-						 self, NULL, NULL);
-	self->protocol_id = gconf_client_notify_add (self->client,
-						     TOTEM_PUBLISH_CONFIG_PROTOCOL,
-						     totem_publish_plugin_protocol_changed_cb,
-						     self, NULL, NULL);
+	g_signal_connect (priv->gsettings, "changed::name", (GCallback) totem_publish_plugin_name_changed_cb, self);
+	g_signal_connect (priv->gsettings, "changed::protocol", (GCallback) totem_publish_plugin_protocol_changed_cb, self);
 
 	protocol = epc_protocol_from_name (protocol_name, EPC_PROTOCOL_HTTPS);
 	service_name = epc_publisher_expand_name (service_pattern, &internal_error);
@@ -587,125 +540,127 @@ impl_activate (PeasActivatable *plugin, GObject *object)
 		g_clear_error (&internal_error);
 	}
 
-	self->monitor = epc_service_monitor_new ("totem", NULL, EPC_PROTOCOL_UNKNOWN);
-	epc_service_monitor_set_skip_our_own (self->monitor, TRUE);
+	priv->monitor = epc_service_monitor_new ("totem", NULL, EPC_PROTOCOL_UNKNOWN);
+	epc_service_monitor_set_skip_our_own (priv->monitor, TRUE);
 
-	ev_sidebar_add_page (EV_SIDEBAR (self->totem->sidebar), "neighbours", _("Neighbors"),
+	/* Translators: computers on the local network which are publishing their playlists over the network */
+	ev_sidebar_add_page (EV_SIDEBAR (priv->totem->sidebar), "neighbours", _("Neighbors"),
 			     totem_publish_plugin_create_neigbours_page (self, builder));
 	g_object_unref (builder);
 
-	self->publisher = epc_publisher_new (service_name, "totem", NULL);
-	epc_publisher_set_protocol (self->publisher, protocol);
+	priv->publisher = epc_publisher_new (service_name, "totem", NULL);
+	epc_publisher_set_protocol (priv->publisher, protocol);
 
 	g_free (protocol_name);
 	g_free (service_name);
 
-	epc_publisher_add_handler (self->publisher, "playlist.pls",
+	epc_publisher_add_handler (priv->publisher, "playlist.pls",
 				   totem_publish_plugin_playlist_cb,
 				   self, NULL);
-	epc_publisher_add_bookmark (self->publisher, "playlist.pls", NULL);
+	epc_publisher_add_bookmark (priv->publisher, "playlist.pls", NULL);
 
-	self->item_added_id = g_signal_connect (self->totem->playlist, "changed",
+	priv->item_added_id = g_signal_connect (priv->totem->playlist, "changed",
 		G_CALLBACK (totem_publish_plugin_playlist_changed_cb), self);
-	self->item_added_id = g_signal_connect (self->totem->playlist, "item-added",
+	priv->item_added_id = g_signal_connect (priv->totem->playlist, "item-added",
 		G_CALLBACK (totem_publish_plugin_playlist_item_added_cb), self);
-	self->item_removed_id = g_signal_connect (self->totem->playlist, "item-removed",
+	priv->item_removed_id = g_signal_connect (priv->totem->playlist, "item-removed",
 		G_CALLBACK (totem_publish_plugin_playlist_item_removed_cb), self);
 
 	G_UNLOCK (totem_publish_plugin_lock);
 
-	totem_playlist_foreach (self->totem->playlist,
+	totem_playlist_foreach (priv->totem->playlist,
 				totem_publish_plugin_playlist_item_added_cb, self);
 
-	totem_publish_plugin_playlist_changed_cb (self->totem->playlist, self);
+	totem_publish_plugin_playlist_changed_cb (priv->totem->playlist, self);
 
-	epc_publisher_run_async (self->publisher, NULL);
+	epc_publisher_run_async (priv->publisher, NULL);
 
 	return;
 }
 
 static void
-impl_deactivate (PeasActivatable *plugin, GObject *totem)
+impl_deactivate (PeasActivatable *plugin)
 {
 	TotemPublishPlugin *self = TOTEM_PUBLISH_PLUGIN (plugin);
+	TotemPublishPluginPrivate *priv = self->priv;
 	TotemPlaylist *playlist = NULL;
 
 	G_LOCK (totem_publish_plugin_lock);
 
-	if (self->totem)
-		playlist = self->totem->playlist;
+	if (priv->totem)
+		playlist = priv->totem->playlist;
 
-	if (self->scanning_id) {
-		g_source_remove (self->scanning_id);
-		self->scanning_id = 0;
+	if (priv->scanning_id) {
+		g_source_remove (priv->scanning_id);
+		priv->scanning_id = 0;
 	}
 
-	if (playlist && self->item_added_id) {
-		g_signal_handler_disconnect (playlist, self->item_added_id);
-		self->item_added_id = 0;
+	if (playlist && priv->item_added_id) {
+		g_signal_handler_disconnect (playlist, priv->item_added_id);
+		priv->item_added_id = 0;
 	}
 
-	if (playlist && self->item_removed_id) {
-		g_signal_handler_disconnect (playlist, self->item_removed_id);
-		self->item_removed_id = 0;
+	if (playlist && priv->item_removed_id) {
+		g_signal_handler_disconnect (playlist, priv->item_removed_id);
+		priv->item_removed_id = 0;
 	}
 
-	if (self->monitor) {
-		g_object_unref (self->monitor);
-		self->monitor = NULL;
+	if (priv->monitor) {
+		g_object_unref (priv->monitor);
+		priv->monitor = NULL;
 	}
 
-	if (self->publisher) {
-		epc_publisher_quit (self->publisher);
-		g_object_unref (self->publisher);
-		self->publisher = NULL;
+	if (priv->publisher) {
+		epc_publisher_quit (priv->publisher);
+		g_object_unref (priv->publisher);
+		priv->publisher = NULL;
 	}
 
-	if (self->totem) {
-		gconf_client_notify_remove (self->client, self->name_id);
-		gconf_client_notify_remove (self->client, self->protocol_id);
-		gconf_client_remove_dir (self->client, TOTEM_PUBLISH_CONFIG_ROOT, NULL);
+	if (priv->gsettings != NULL)
+		g_object_unref (priv->gsettings);
+	priv->gsettings = NULL;
 
-		ev_sidebar_remove_page (EV_SIDEBAR (self->totem->sidebar), "neighbours");
+	if (priv->totem) {
+		ev_sidebar_remove_page (EV_SIDEBAR (priv->totem->sidebar), "neighbours");
 
-		g_object_unref (self->totem);
-		self->totem = NULL;
+		g_object_unref (priv->totem);
+		priv->totem = NULL;
 	}
 
-	if (self->settings) {
-		gtk_widget_destroy (self->settings);
-		self->settings = NULL;
+	if (priv->settings) {
+		gtk_widget_destroy (priv->settings);
+		priv->settings = NULL;
 	}
 
-	if (self->playlist) {
-		g_slist_foreach (self->playlist, (GFunc) g_free, NULL);
-		g_slist_free (self->playlist);
-		self->playlist = NULL;
+	if (priv->playlist) {
+		g_slist_foreach (priv->playlist, (GFunc) g_free, NULL);
+		g_slist_free (priv->playlist);
+		priv->playlist = NULL;
 	}
 
 	G_UNLOCK (totem_publish_plugin_lock);
 
-	self->scanning = NULL;
+	priv->scanning = NULL;
 }
 
 static GtkWidget *
-impl_create_configure_widget (PeasUIConfigurable *configurable)
+impl_create_configure_widget (PeasGtkConfigurable *configurable)
 {
 	TotemPublishPlugin *self = TOTEM_PUBLISH_PLUGIN (configurable);
 	gchar *service_name, *protocol_name;
 	GtkBuilder *builder;
 	GtkWidget *widget;
 	EpcProtocol protocol;
-	GConfClient *client;
+	GSettings *settings;
 
 	/* This function has to be independent of the rest of the plugin, as it's executed under a different plugin instance.
 	 * FIXME: bgo#624073 */
 	builder = totem_plugin_load_interface ("publish", "publish-plugin.ui", TRUE, NULL, self);
 
-	client = gconf_client_get_default ();
-	service_name = gconf_client_get_string (client, TOTEM_PUBLISH_CONFIG_NAME, NULL);
-	protocol_name = gconf_client_get_string (client, TOTEM_PUBLISH_CONFIG_PROTOCOL, NULL);
-	g_object_unref (client);
+	settings = g_settings_new (TOTEM_PUBLISH_SCHEMA);
+	service_name = g_settings_get_string (settings, "name-format");
+	protocol_name = g_settings_get_string (settings, "protocol");
+	g_object_unref (settings);
 
 	protocol = epc_protocol_from_name (protocol_name, EPC_PROTOCOL_HTTPS);
 	g_free (protocol_name);
@@ -719,30 +674,3 @@ impl_create_configure_widget (PeasUIConfigurable *configurable)
 
 	return widget;
 }
-
-static void
-totem_publish_plugin_init (TotemPublishPlugin *self)
-{
-	self->client = gconf_client_get_default ();
-}
-
-static void
-totem_publish_plugin_dispose (GObject *object)
-{
-	TotemPublishPlugin *self = TOTEM_PUBLISH_PLUGIN (object);
-
-	if (self->client != NULL) {
-		g_object_unref (self->client);
-		self->client = NULL;
-	}
-
-	G_OBJECT_CLASS (totem_publish_plugin_parent_class)->dispose (object);
-}
-
-static void
-totem_publish_plugin_class_init (TotemPublishPluginClass *klass)
-{
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	object_class->dispose = totem_publish_plugin_dispose;
-}
-
