@@ -26,6 +26,7 @@
 #include <glib/gi18n.h>
 #include <gst/tag/tag.h>
 #include <string.h>
+#include <libpeas-gtk/peas-gtk-plugin-manager.h>
 
 #include "totem-menu.h"
 #include "totem.h"
@@ -33,7 +34,6 @@
 #include "totem-private.h"
 #include "totem-sidebar.h"
 #include "totem-statusbar.h"
-#include "totem-plugin-manager.h"
 #include "bacon-video-widget.h"
 #include "totem-uri.h"
 
@@ -1235,7 +1235,7 @@ plugins_action_callback (GtkAction *action, Totem *totem)
 					 G_CALLBACK (totem_plugins_response_cb),
 					 NULL, 0);
 
-		manager = totem_plugin_manager_new ();
+		manager = peas_gtk_plugin_manager_new ();
 		gtk_widget_show_all (GTK_WIDGET (manager));
 		gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (totem->plugins))),
 				   manager);
