@@ -28,7 +28,6 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
-#include <gconf/gconf-client.h>
 #include <gio/gio.h>
 #include <string.h>
 
@@ -93,7 +92,8 @@ struct TotemPlaylistPrivate
 	int *shuffled;
 	int current_shuffled, shuffle_len;
 
-	GConfClient *gc;
+	GSettings *settings;
+	GSettings *lockdown_settings;
 
 	/* Used to know the position for drops */
 	GtkTreePath *tree_path;
@@ -1209,7 +1209,7 @@ totem_playlist_key_press (GtkWidget *win, GdkEventKey *event, TotemPlaylist *pla
 	/* Special case some shortcuts */
 	if (event->state != 0) {
 		if ((event->state & GDK_CONTROL_MASK)
-		    && event->keyval == GDK_a) {
+		    && event->keyval == GDK_KEY_a) {
 			gtk_tree_selection_select_all
 				(playlist->priv->selection);
 			return TRUE;
@@ -1227,7 +1227,7 @@ totem_playlist_key_press (GtkWidget *win, GdkEventKey *event, TotemPlaylist *pla
 			|| (event->state & GDK_MOD5_MASK)))
 		return FALSE;
 
-	if (event->keyval == GDK_Delete)
+	if (event->keyval == GDK_KEY_Delete)
 	{
 		playlist_remove_files (playlist);
 		return TRUE;
@@ -1241,22 +1241,23 @@ set_playing_icon (GtkTreeViewColumn *column, GtkCellRenderer *renderer,
 		  GtkTreeModel *model, GtkTreeIter *iter, TotemPlaylist *playlist)
 {
 	TotemPlaylistStatus playing;
-	const char *stock_id;
+	const char *icon_name;
 
 	gtk_tree_model_get (model, iter, PLAYING_COL, &playing, -1);
 
 	switch (playing) {
 		case TOTEM_PLAYLIST_STATUS_PLAYING:
-			stock_id = GTK_STOCK_MEDIA_PLAY;
+			icon_name = "media-playback-start-symbolic";
 			break;
 		case TOTEM_PLAYLIST_STATUS_PAUSED:
-			stock_id = GTK_STOCK_MEDIA_PAUSE;
+			icon_name = "media-playback-pause-symbolic";
 			break;
+		case TOTEM_PLAYLIST_STATUS_NONE:
 		default:
-			stock_id = NULL;
+			icon_name = NULL;
 	}
 
-	g_object_set (renderer, "stock-id", stock_id, NULL);
+	g_object_set (renderer, "icon-name", icon_name, NULL);
 }
 
 static void
@@ -1421,20 +1422,16 @@ init_treeview (GtkWidget *treeview, TotemPlaylist *playlist)
 }
 
 static void
-update_repeat_cb (GConfClient *client, guint cnxn_id,
-		GConfEntry *entry, TotemPlaylist *playlist)
+update_repeat_cb (GSettings *settings, const gchar *key, TotemPlaylist *playlist)
 {
-	gboolean repeat;
-
-	repeat = gconf_value_get_bool (entry->value);
-	playlist->priv->repeat = (repeat != FALSE);
+	playlist->priv->repeat = g_settings_get_boolean (settings, "repeat");
 
 	g_signal_emit (G_OBJECT (playlist),
 			totem_playlist_table_signals[CHANGED], 0,
 			NULL);
 	g_signal_emit (G_OBJECT (playlist),
 			totem_playlist_table_signals[REPEAT_TOGGLED], 0,
-			repeat, NULL);
+			playlist->priv->repeat, NULL);
 }
 
 typedef struct {
@@ -1510,14 +1507,11 @@ ensure_shuffled (TotemPlaylist *playlist)
 }
 
 static void
-update_shuffle_cb (GConfClient *client, guint cnxn_id,
-		GConfEntry *entry, TotemPlaylist *playlist)
+update_shuffle_cb (GSettings *settings, const gchar *key, TotemPlaylist *playlist)
 {
-	gboolean shuffle;
+	playlist->priv->shuffle = g_settings_get_boolean (settings, "shuffle");
 
-	shuffle = gconf_value_get_bool (entry->value);
-	playlist->priv->shuffle = shuffle;
-	if (shuffle == FALSE) {
+	if (playlist->priv->shuffle == FALSE) {
 		g_free (playlist->priv->shuffled);
 		playlist->priv->shuffled = NULL;
 		playlist->priv->shuffle_len = 0;
@@ -1530,49 +1524,32 @@ update_shuffle_cb (GConfClient *client, guint cnxn_id,
 			NULL);
 	g_signal_emit (G_OBJECT (playlist),
 			totem_playlist_table_signals[SHUFFLE_TOGGLED], 0,
-			shuffle, NULL);
+			playlist->priv->shuffle, NULL);
 }
 
 static void
-update_lockdown (GConfClient *client, guint cnxn_id,
-		GConfEntry *entry, TotemPlaylist *playlist)
+update_lockdown_cb (GSettings *settings, const gchar *key, TotemPlaylist *playlist)
 {
-	playlist->priv->disable_save_to_disk = gconf_client_get_bool
-			(playlist->priv->gc,
-			"/desktop/gnome/lockdown/disable_save_to_disk", NULL) != FALSE;
+	playlist->priv->disable_save_to_disk = g_settings_get_boolean (settings, "disable-save-to-disk");
 	totem_playlist_update_save_button (playlist);
 }
 
 static void
 init_config (TotemPlaylist *playlist)
 {
-	playlist->priv->gc = gconf_client_get_default ();
+	playlist->priv->settings = g_settings_new (TOTEM_GSETTINGS_SCHEMA);
+	playlist->priv->lockdown_settings = g_settings_new ("org.gnome.desktop.lockdown");
 
-	playlist->priv->disable_save_to_disk = gconf_client_get_bool
-	       		(playlist->priv->gc,
-			"/desktop/gnome/lockdown/disable_save_to_disk", NULL) != FALSE;
+	playlist->priv->disable_save_to_disk = g_settings_get_boolean (playlist->priv->lockdown_settings, "disable-save-to-disk");
 	totem_playlist_update_save_button (playlist);
 
-	gconf_client_add_dir (playlist->priv->gc, GCONF_PREFIX,
-			GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
-	gconf_client_notify_add (playlist->priv->gc, GCONF_PREFIX"/repeat",
-			(GConfClientNotifyFunc) update_repeat_cb,
-			playlist, NULL, NULL);
-	gconf_client_notify_add (playlist->priv->gc, GCONF_PREFIX"/shuffle",
-			(GConfClientNotifyFunc) update_shuffle_cb,
-			playlist, NULL, NULL);
+	g_signal_connect (playlist->priv->lockdown_settings, "changed::disable-save-to-disk", (GCallback) update_lockdown_cb, playlist);
 
-	gconf_client_add_dir (playlist->priv->gc, "/desktop/gnome/lockdown",
-			GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
-	gconf_client_notify_add (playlist->priv->gc,
-			"/desktop/gnome/lockdown/disable_save_to_disk",
-			(GConfClientNotifyFunc) update_lockdown,
-			playlist, NULL, NULL);
+	playlist->priv->repeat = g_settings_get_boolean (playlist->priv->settings, "repeat");
+	playlist->priv->shuffle = g_settings_get_boolean (playlist->priv->settings, "shuffle");
 
-	playlist->priv->repeat = gconf_client_get_bool (playlist->priv->gc,
-			GCONF_PREFIX"/repeat", NULL) != FALSE;
-	playlist->priv->shuffle = gconf_client_get_bool (playlist->priv->gc,
-			GCONF_PREFIX"/shuffle", NULL) != FALSE;
+	g_signal_connect (playlist->priv->settings, "changed::repeat", (GCallback) update_repeat_cb, playlist);
+	g_signal_connect (playlist->priv->settings, "changed::shuffle", (GCallback) update_shuffle_cb, playlist);
 }
 
 static void
@@ -1647,6 +1624,14 @@ totem_playlist_dispose (GObject *object)
 		playlist->priv->action_group = NULL;
 	}
 
+	if (playlist->priv->settings != NULL)
+		g_object_unref (playlist->priv->settings);
+	playlist->priv->settings = NULL;
+
+	if (playlist->priv->lockdown_settings != NULL)
+		g_object_unref (playlist->priv->lockdown_settings);
+	playlist->priv->lockdown_settings = NULL;
+
 	G_OBJECT_CLASS (totem_playlist_parent_class)->dispose (object);
 }
 
@@ -2526,8 +2511,7 @@ totem_playlist_set_repeat (TotemPlaylist *playlist, gboolean repeat)
 {
 	g_return_if_fail (TOTEM_IS_PLAYLIST (playlist));
 
-	gconf_client_set_bool (playlist->priv->gc, GCONF_PREFIX"/repeat",
-			repeat, NULL);
+	g_settings_set_boolean (playlist->priv->settings, "repeat", repeat);
 }
 
 gboolean
@@ -2543,8 +2527,7 @@ totem_playlist_set_shuffle (TotemPlaylist *playlist, gboolean shuffle)
 {
 	g_return_if_fail (TOTEM_IS_PLAYLIST (playlist));
 
-	gconf_client_set_bool (playlist->priv->gc, GCONF_PREFIX"/shuffle",
-			shuffle, NULL);
+	g_settings_set_boolean (playlist->priv->settings, "shuffle", shuffle);
 }
 
 void
