@@ -35,6 +35,7 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 
+#include "bacon-video-widget-enums.h"
 #include "totem.h"
 #include "totem-private.h"
 #include "totem-preferences.h"
@@ -44,15 +45,9 @@
 #include "totem-plugins-engine.h"
 
 /* Callback functions for GtkBuilder */
-G_MODULE_EXPORT void checkbutton1_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
 G_MODULE_EXPORT void checkbutton2_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
-G_MODULE_EXPORT void checkbutton3_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
 G_MODULE_EXPORT void audio_screensaver_button_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
-G_MODULE_EXPORT void no_deinterlace_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
-G_MODULE_EXPORT void remember_position_checkbutton_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
-G_MODULE_EXPORT void connection_combobox_changed (GtkComboBox *combobox, Totem *totem);
 G_MODULE_EXPORT void visual_menu_changed (GtkComboBox *combobox, Totem *totem);
-G_MODULE_EXPORT void visual_quality_menu_changed (GtkComboBox *combobox, Totem *totem);
 G_MODULE_EXPORT void brightness_changed (GtkRange *range, Totem *totem);
 G_MODULE_EXPORT void contrast_changed (GtkRange *range, Totem *totem);
 G_MODULE_EXPORT void saturation_changed (GtkRange *range, Totem *totem);
@@ -61,36 +56,6 @@ G_MODULE_EXPORT void tpw_color_reset_clicked_cb (GtkButton *button, Totem *totem
 G_MODULE_EXPORT void audio_out_menu_changed (GtkComboBox *combobox, Totem *totem);
 G_MODULE_EXPORT void font_set_cb (GtkFontButton * fb, Totem * totem);
 G_MODULE_EXPORT void encoding_set_cb (GtkComboBox *cb, Totem *totem);
-G_MODULE_EXPORT void font_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, Totem *totem);
-G_MODULE_EXPORT void encoding_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, Totem *totem);
-
-static void
-totem_action_info (char *reason, Totem *totem)
-{
-	GtkWidget *parent, *error_dialog;
-
-	if (totem == NULL)
-		parent = NULL;
-	else
-		parent = totem->prefs;
-
-	error_dialog =
-		gtk_message_dialog_new (GTK_WINDOW (parent),
-				GTK_DIALOG_MODAL,
-				GTK_MESSAGE_INFO,
-				GTK_BUTTONS_OK,
-				"%s", reason);
-	gtk_container_set_border_width (GTK_CONTAINER (error_dialog), 5);
-	gtk_dialog_set_default_response (GTK_DIALOG (error_dialog),
-			GTK_RESPONSE_OK);
-	g_signal_connect (G_OBJECT (error_dialog), "destroy", G_CALLBACK
-			(gtk_widget_destroy), error_dialog);
-	g_signal_connect (G_OBJECT (error_dialog), "response", G_CALLBACK
-			(gtk_widget_destroy), error_dialog);
-	gtk_window_set_modal (GTK_WINDOW (error_dialog), TRUE);
-
-	gtk_widget_show (error_dialog);
-}
 
 static gboolean
 ask_show_visuals (Totem *totem)
@@ -117,25 +82,12 @@ ask_show_visuals (Totem *totem)
 	return (answer == GTK_RESPONSE_YES ? TRUE : FALSE);
 }
 
-void
-checkbutton1_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
-{
-	gboolean value;
-
-	value = gtk_toggle_button_get_active (togglebutton);
-	gconf_client_set_bool (totem->gc, GCONF_PREFIX"/auto_resize",
-			value, NULL);
-	bacon_video_widget_set_auto_resize
-		(BACON_VIDEO_WIDGET (totem->bvw), value);
-}
-
 static void
 totem_prefs_set_show_visuals (Totem *totem, gboolean value)
 {
 	GtkWidget *item;
 
-	gconf_client_set_bool (totem->gc,
-			GCONF_PREFIX"/show_vfx", value, NULL);
+	g_settings_set_boolean (totem->settings, "show-visualizations", value);
 
 	item = GTK_WIDGET (gtk_builder_get_object (totem->xml, "tpw_visuals_type_label"));
 	gtk_widget_set_sensitive (item, value);
@@ -148,7 +100,7 @@ totem_prefs_set_show_visuals (Totem *totem, gboolean value)
 			"tpw_visuals_size_combobox"));
 	gtk_widget_set_sensitive (item, value);
 
-	bacon_video_widget_set_show_visuals
+	bacon_video_widget_set_show_visualizations
 		(BACON_VIDEO_WIDGET (totem->bvw), value);
 }
 
@@ -163,8 +115,7 @@ checkbutton2_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
 	{
 		if (ask_show_visuals (totem) == FALSE)
 		{
-			gconf_client_set_bool (totem->gc,
-					GCONF_PREFIX"/show_vfx", FALSE, NULL);
+			g_settings_set_boolean (totem->settings, "show-visualizations", FALSE);
 			gtk_toggle_button_set_active (togglebutton, FALSE);
 			return;
 		}
@@ -173,119 +124,17 @@ checkbutton2_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
 	totem_prefs_set_show_visuals (totem, value);
 }
 
-void
-checkbutton3_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
-{
-	gboolean value;
-
-	value = gtk_toggle_button_get_active (togglebutton);
-
-	gconf_client_set_bool (totem->gc,
-			       GCONF_PREFIX"/autoload_subtitles", value, NULL);
-	totem->autoload_subs = value;
-}
-
 void
 audio_screensaver_button_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
 {
 	gboolean value;
 
 	value = gtk_toggle_button_get_active (togglebutton);
-
-	gconf_client_set_bool (totem->gc,
-			       GCONF_PREFIX"/lock_screensaver_on_audio",
-			       value, NULL);
-}
-
-void
-no_deinterlace_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
-{
-	gboolean value;
-
-	value = gtk_toggle_button_get_active (togglebutton);
-
-	bacon_video_widget_set_deinterlacing (totem->bvw, !value);
-	gconf_client_set_bool (totem->gc,
-			       GCONF_PREFIX"/disable_deinterlacing",
-			       value, NULL);
+	g_settings_set_boolean (totem->settings, "lock-screensaver-on-audio", value);
 }
 
 static void
-no_deinterlace_changed_cb (GConfClient *client,
-			   guint cnxn_id,
-			   GConfEntry *entry,
-			   Totem *totem)
-{
-	GObject *button;
-	gboolean value;
-
-	button = gtk_builder_get_object (totem->xml, "tpw_no_deinterlace_checkbutton");
-
-	g_signal_handlers_block_matched (button,
-					 G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, totem);
-
-	value = gconf_client_get_bool (totem->gc,
-				       GCONF_PREFIX"/disable_deinterlacing", NULL);
-
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), value);
-	bacon_video_widget_set_deinterlacing (totem->bvw, !value);
-
-	g_signal_handlers_unblock_matched (button,
-					   G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, totem);
-}
-
-void
-remember_position_checkbutton_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
-{
-	gboolean value;
-
-	value = gtk_toggle_button_get_active (togglebutton);
-
-	gconf_client_set_bool (totem->gc,
-			       GCONF_PREFIX"/remember_position",
-			       value, NULL);
-	totem->remember_position = value;
-}
-
-static void
-remember_position_changed_cb (GConfClient *client, guint cnxn_id,
-                              GConfEntry *entry, Totem *totem)
-{
-	GObject *item;
-
-	item = gtk_builder_get_object (totem->xml, "tpw_remember_position_checkbutton");
-	g_signal_handlers_block_by_func (item, remember_position_checkbutton_toggled_cb,
-					 totem);
-
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item),
-				      gconf_client_get_bool (totem->gc,
-							     GCONF_PREFIX"/remember_position", NULL));
-
-	g_signal_handlers_unblock_by_func (item, remember_position_checkbutton_toggled_cb,
-					   totem);
-}
-
-static void
-auto_resize_changed_cb (GConfClient *client, guint cnxn_id,
-		GConfEntry *entry, Totem *totem)
-{
-	GObject *item;
-
-	item = gtk_builder_get_object (totem->xml, "tpw_display_checkbutton");
-	g_signal_handlers_disconnect_by_func (item,
-			checkbutton1_toggled_cb, totem);
-
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item),
-			gconf_client_get_bool (totem->gc,
-				GCONF_PREFIX"/auto_resize", NULL));
-
-	g_signal_connect (item, "toggled",
-			G_CALLBACK (checkbutton1_toggled_cb), totem);
-}
-
-static void
-show_vfx_changed_cb (GConfClient *client, guint cnxn_id,
-		     GConfEntry *entry, Totem *totem)
+show_vfx_changed_cb (GSettings *settings, const gchar *key, TotemObject *totem)
 {
 	GObject *item;
 
@@ -293,27 +142,20 @@ show_vfx_changed_cb (GConfClient *client, guint cnxn_id,
 	g_signal_handlers_disconnect_by_func (item,
 			checkbutton2_toggled_cb, totem);
 
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item),
-			gconf_client_get_bool (totem->gc,
-				GCONF_PREFIX"/show_vfx", NULL));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), g_settings_get_boolean (totem->settings, "show-visualizations"));
 
 	g_signal_connect (item, "toggled",
 			G_CALLBACK (checkbutton2_toggled_cb), totem);
 }
 
 static void
-disable_kbd_shortcuts_changed_cb (GConfClient *client,
-				  guint cnxn_id,
-				  GConfEntry *entry,
-				  Totem *totem)
+disable_kbd_shortcuts_changed_cb (GSettings *settings, const gchar *key, TotemObject *totem)
 {
-	totem->disable_kbd_shortcuts = gconf_client_get_bool (totem->gc,
-							      GCONF_PREFIX"/disable_keyboard_shortcuts", NULL);
+	totem->disable_kbd_shortcuts = g_settings_get_boolean (totem->settings, "disable-keyboard-shortcuts");
 }
 
 static void
-lock_screensaver_on_audio_changed_cb (GConfClient *client, guint cnxn_id,
-				      GConfEntry *entry, Totem *totem)
+lock_screensaver_on_audio_changed_cb (GSettings *settings, const gchar *key, TotemObject *totem)
 {
 	GObject *item, *radio;
 	gboolean value;
@@ -322,8 +164,7 @@ lock_screensaver_on_audio_changed_cb (GConfClient *client, guint cnxn_id,
 	g_signal_handlers_disconnect_by_func (item,
 					      audio_screensaver_button_toggled_cb, totem);
 
-	value = gconf_client_get_bool (totem->gc,
-				       GCONF_PREFIX"/lock_screensaver_on_audio", NULL);
+	value = g_settings_get_boolean (totem->settings, "lock-screensaver-on-audio");
 	if (value != FALSE) {
 		radio = gtk_builder_get_object (totem->xml, "tpw_audio_toggle_button");
 	} else {
@@ -335,69 +176,19 @@ lock_screensaver_on_audio_changed_cb (GConfClient *client, guint cnxn_id,
 			  G_CALLBACK (audio_screensaver_button_toggled_cb), totem);
 }
 
-static void
-autoload_subtitles_changed_cb (GConfClient *client, guint cnxn_id,
-			       GConfEntry *entry, Totem *totem)
-{
-	GObject *item;
-
-	item = gtk_builder_get_object (totem->xml, "tpw_auto_subtitles_checkbutton");
-	g_signal_handlers_disconnect_by_func (item,
-			checkbutton3_toggled_cb, totem);
-
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item),
-			gconf_client_get_bool (totem->gc,
-				GCONF_PREFIX"/autoload_subtitles", NULL));
-
-	g_signal_connect (item, "toggled",
-			G_CALLBACK (checkbutton3_toggled_cb), totem);
-}
-
-void
-connection_combobox_changed (GtkComboBox *combobox, Totem *totem)
-{
-	int i;
-
-	i = gtk_combo_box_get_active (combobox);
-	bacon_video_widget_set_connection_speed
-		(BACON_VIDEO_WIDGET (totem->bvw), i);
-}
-
 void
 visual_menu_changed (GtkComboBox *combobox, Totem *totem)
 {
 	GList *list;
-	char *old_name, *name;
+	const gchar *name;
 	int i;
 
 	i = gtk_combo_box_get_active (combobox);
-	list = bacon_video_widget_get_visuals_list (totem->bvw);
+	list = bacon_video_widget_get_visualization_list (totem->bvw);
 	name = g_list_nth_data (list, i);
 
-	old_name = gconf_client_get_string (totem->gc,
-			GCONF_PREFIX"/visual", NULL);
-
-	if (old_name == NULL || strcmp (old_name, name) != 0)
-	{
-		gconf_client_set_string (totem->gc, GCONF_PREFIX"/visual",
-				name, NULL);
-
-		if (bacon_video_widget_set_visuals (totem->bvw, name) != FALSE)
-			totem_action_info (_("Changing the visuals effect type will require a restart to take effect."), totem);
-	}
-
-	g_free (old_name);
-}
-
-void
-visual_quality_menu_changed (GtkComboBox *combobox, Totem *totem)
-{
-	int i;
-
-	i = gtk_combo_box_get_active (combobox);
-	gconf_client_set_int (totem->gc,
-			GCONF_PREFIX"/visual_quality", i, NULL);
-	bacon_video_widget_set_visuals_quality (totem->bvw, i);
+	g_settings_set_string (totem->settings, "visualization-name", name);
+	bacon_video_widget_set_visualization (totem->bvw, name);
 }
 
 void
@@ -462,16 +253,9 @@ void
 audio_out_menu_changed (GtkComboBox *combobox, Totem *totem)
 {
 	BvwAudioOutType audio_out;
-	gboolean need_restart;
 
 	audio_out = gtk_combo_box_get_active (combobox);
-	need_restart = bacon_video_widget_set_audio_out_type (totem->bvw, audio_out);
-	if (need_restart != FALSE) {
-		totem_action_info (_("The change of audio output type will "
-					"only take effect when Totem is "
-					"restarted."),
-				totem);
-	}
+	bacon_video_widget_set_audio_out_type (totem->bvw, audio_out);
 }
 
 void
@@ -480,8 +264,7 @@ font_set_cb (GtkFontButton * fb, Totem * totem)
 	const gchar *font;
 
 	font = gtk_font_button_get_font_name (fb);
-	gconf_client_set_string (totem->gc, GCONF_PREFIX"/subtitle_font",
-				 font, NULL);
+	g_settings_set_string (totem->settings, "subtitle-font", font);
 }
 
 void
@@ -491,48 +274,78 @@ encoding_set_cb (GtkComboBox *cb, Totem *totem)
 
 	encoding = totem_subtitle_encoding_get_selected (cb);
 	if (encoding)
-		gconf_client_set_string (totem->gc,
-				GCONF_PREFIX"/subtitle_encoding",
-				encoding, NULL);
+		g_settings_set_string (totem->settings, "subtitle-encoding", encoding);
 }
 
-void
-font_changed_cb (GConfClient *client, guint cnxn_id,
-		 GConfEntry *entry, Totem *totem)
+static void
+font_changed_cb (GSettings *settings, const gchar *key, TotemObject *totem)
 {
-	const gchar *font;
+	gchar *font;
 	GtkFontButton *item;
 
 	item = GTK_FONT_BUTTON (gtk_builder_get_object (totem->xml, "font_sel_button"));
-	font = gconf_value_get_string (entry->value);
+	font = g_settings_get_string (settings, "subtitle-font");
 	gtk_font_button_set_font_name (item, font);
 	bacon_video_widget_set_subtitle_font (totem->bvw, font);
+	g_free (font);
 }
 
-void
-encoding_changed_cb (GConfClient *client, guint cnxn_id,
-		 GConfEntry *entry, Totem *totem)
+static void
+encoding_changed_cb (GSettings *settings, const gchar *key, TotemObject *totem)
 {
-	const gchar *encoding;
+	gchar *encoding;
 	GtkComboBox *item;
 
 	item = GTK_COMBO_BOX (gtk_builder_get_object (totem->xml, "subtitle_encoding_combo"));
-	encoding = gconf_value_get_string (entry->value);
+	encoding = g_settings_get_string (settings, "subtitle-encoding");
 	totem_subtitle_encoding_set (item, encoding);
 	bacon_video_widget_set_subtitle_encoding (totem->bvw, encoding);
+	g_free (encoding);
+}
+
+static gboolean
+int_enum_get_mapping (GValue *value, GVariant *variant, GEnumClass *enum_class)
+{
+	GEnumValue *enum_value;
+	const gchar *nick;
+
+	g_return_val_if_fail (G_IS_ENUM_CLASS (enum_class), FALSE);
+
+	nick = g_variant_get_string (variant, NULL);
+	enum_value = g_enum_get_value_by_nick (enum_class, nick);
+
+	if (enum_value == NULL)
+		return FALSE;
+
+	g_value_set_int (value, enum_value->value);
+
+	return TRUE;
+}
+
+static GVariant *
+int_enum_set_mapping (const GValue *value, const GVariantType *expected_type, GEnumClass *enum_class)
+{
+	GEnumValue *enum_value;
+
+	g_return_val_if_fail (G_IS_ENUM_CLASS (enum_class), NULL);
+
+	enum_value = g_enum_get_value (enum_class, g_value_get_int (value));
+
+	if (enum_value == NULL)
+		return NULL;
+
+	return g_variant_new_string (enum_value->value_nick);
 }
 
 void
 totem_setup_preferences (Totem *totem)
 {
-	GtkWidget *menu, *content_area;
-	gboolean show_visuals, auto_resize, is_local, no_deinterlace, lock_screensaver_on_audio;
-	int connection_speed;
+	GtkWidget *menu, *content_area, *bvw;
+	gboolean show_visuals, is_local, lock_screensaver_on_audio;
 	guint i, hidden;
 	char *visual, *font, *encoding;
 	GList *list, *l;
 	BvwAudioOutType audio_out;
-	GConfValue *value;
 	GObject *item;
 
 	static struct {
@@ -546,17 +359,10 @@ totem_setup_preferences (Totem *totem)
 		{ "tpw_hue_scale", BVW_VIDEO_HUE, "tpw_hue_label" }
 	};
 
-	g_return_if_fail (totem->gc != NULL);
+	g_return_if_fail (totem->settings != NULL);
 
 	is_local = totem_display_is_local ();
-
-	gconf_client_add_dir (totem->gc, GCONF_PREFIX,
-			GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
-	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/auto_resize",
-			(GConfClientNotifyFunc) auto_resize_changed_cb,
-			totem, NULL, NULL);
-	gconf_client_add_dir (totem->gc, "/desktop/gnome/lockdown",
-			GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+	bvw = totem_get_video_widget (totem);
 
 	/* Work-around builder dialogue not parenting properly for
 	 * On top windows */
@@ -567,7 +373,6 @@ totem_setup_preferences (Totem *totem)
 			GTK_STOCK_CLOSE,
 			GTK_RESPONSE_ACCEPT,
 			NULL);
-	gtk_dialog_set_has_separator (GTK_DIALOG (totem->prefs), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (totem->prefs), 5);
 	content_area = gtk_dialog_get_content_area (GTK_DIALOG (totem->prefs));
 	gtk_box_set_spacing (GTK_BOX (content_area), 2);
@@ -584,53 +389,39 @@ totem_setup_preferences (Totem *totem)
                           G_CALLBACK (gtk_widget_destroyed), &totem->prefs);
 
 	/* Remember position */
-	totem->remember_position = gconf_client_get_bool (totem->gc,
-			GCONF_PREFIX"/remember_position", NULL);
 	item = gtk_builder_get_object (totem->xml, "tpw_remember_position_checkbutton");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), totem->remember_position);
-	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/remember_position",
-	                         (GConfClientNotifyFunc) remember_position_changed_cb,
-	                         totem, NULL, NULL);
+	g_settings_bind (totem->settings, "remember-position", item, "active", G_SETTINGS_BIND_DEFAULT);
+	g_settings_bind (totem->settings, "remember-position", totem, "remember-position", G_SETTINGS_BIND_DEFAULT);
 
 	/* Auto-resize */
-	auto_resize = gconf_client_get_bool (totem->gc,
-			GCONF_PREFIX"/auto_resize", NULL);
 	item = gtk_builder_get_object (totem->xml, "tpw_display_checkbutton");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), auto_resize);
-	bacon_video_widget_set_auto_resize
-		(BACON_VIDEO_WIDGET (totem->bvw), auto_resize);
+	g_settings_bind (totem->settings, "auto-resize", item, "active", G_SETTINGS_BIND_DEFAULT);
+	g_settings_bind (totem->settings, "auto-resize", bvw, "auto-resize", G_SETTINGS_BIND_DEFAULT);
 
 	/* Screensaver audio locking */
-	lock_screensaver_on_audio = gconf_client_get_bool (totem->gc,
-							   GCONF_PREFIX"/lock_screensaver_on_audio", NULL);
+	lock_screensaver_on_audio = g_settings_get_boolean (totem->settings, "lock-screensaver-on-audio");
 	if (lock_screensaver_on_audio != FALSE)
 		item = gtk_builder_get_object (totem->xml, "tpw_audio_toggle_button");
 	else
 		item = gtk_builder_get_object (totem->xml, "tpw_video_toggle_button");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), TRUE);
-	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/lock_screensaver_on_audio",
-				 (GConfClientNotifyFunc) lock_screensaver_on_audio_changed_cb,
-				 totem, NULL, NULL);
+	g_signal_connect (totem->settings, "changed::lock-screensaver-on-audio", (GCallback) lock_screensaver_on_audio_changed_cb, totem);
 
 	/* Disable deinterlacing */
 	item = gtk_builder_get_object (totem->xml, "tpw_no_deinterlace_checkbutton");
-	no_deinterlace = gconf_client_get_bool (totem->gc,
-						GCONF_PREFIX"/disable_deinterlacing", NULL);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), no_deinterlace);
-	bacon_video_widget_set_deinterlacing (totem->bvw, !no_deinterlace);
-	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/disable_deinterlacing",
-				 (GConfClientNotifyFunc) no_deinterlace_changed_cb,
-				 totem, NULL, NULL);
+	g_settings_bind (totem->settings, "disable-deinterlacing", item, "active", G_SETTINGS_BIND_DEFAULT);
+	g_settings_bind (totem->settings, "disable-deinterlacing", bvw, "deinterlacing", G_SETTINGS_BIND_DEFAULT | G_SETTINGS_BIND_INVERT_BOOLEAN);
 
 	/* Connection Speed */
-	connection_speed = bacon_video_widget_get_connection_speed (totem->bvw);
 	item = gtk_builder_get_object (totem->xml, "tpw_speed_combobox");
-	gtk_combo_box_set_active (GTK_COMBO_BOX (item), connection_speed);
+	g_settings_bind (totem->settings, "connection-speed", bvw, "connection-speed", G_SETTINGS_BIND_DEFAULT);
+	g_settings_bind_with_mapping (totem->settings, "connection-speed", item, "active", G_SETTINGS_BIND_DEFAULT,
+	                              (GSettingsBindGetMapping) int_enum_get_mapping, (GSettingsBindSetMapping) int_enum_set_mapping,
+	                              g_type_class_ref (BVW_TYPE_CONNECTION_SPEED), (GDestroyNotify) g_type_class_unref);
 
 	/* Enable visuals */
 	item = gtk_builder_get_object (totem->xml, "tpw_visuals_checkbutton");
-	show_visuals = gconf_client_get_bool (totem->gc,
-			GCONF_PREFIX"/show_vfx", NULL);
+	show_visuals = g_settings_get_boolean (totem->settings, "show-visualizations");
 	if (is_local == FALSE && show_visuals != FALSE)
 		show_visuals = ask_show_visuals (totem);
 
@@ -640,56 +431,56 @@ totem_setup_preferences (Totem *totem)
 	totem_prefs_set_show_visuals (totem, show_visuals);
 	g_signal_connect (item, "toggled", G_CALLBACK (checkbutton2_toggled_cb), totem);
 
-	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/show_vfx",
-			(GConfClientNotifyFunc) show_vfx_changed_cb,
-			totem, NULL, NULL);
+	g_signal_connect (totem->settings, "changed::show-visualizations", (GCallback) show_vfx_changed_cb, totem);
 
 	/* Auto-load subtitles */
 	item = gtk_builder_get_object (totem->xml, "tpw_auto_subtitles_checkbutton");
-	totem->autoload_subs = gconf_client_get_bool (totem->gc,
-					      GCONF_PREFIX"/autoload_subtitles", NULL);
+	g_settings_bind (totem->settings, "autoload-subtitles", item, "active", G_SETTINGS_BIND_DEFAULT);
+	g_settings_bind (totem->settings, "autoload-subtitles", totem, "autoload-subtitles", G_SETTINGS_BIND_DEFAULT);
 
-	g_signal_handlers_disconnect_by_func (item, checkbutton3_toggled_cb, totem);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), totem->autoload_subs);
-	g_signal_connect (item, "toggled", G_CALLBACK (checkbutton3_toggled_cb), totem);
-
-	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/autoload_subtitles",
-				 (GConfClientNotifyFunc) autoload_subtitles_changed_cb,
-				 totem, NULL, NULL);
+	/* Auto-load external chapters */
+	item = gtk_builder_get_object (totem->xml, "tpw_auto_chapters_checkbutton");
+	g_settings_bind (totem->settings, "autoload-chapters", item, "active", G_SETTINGS_BIND_DEFAULT);
 
 	/* Visuals list */
-	list = bacon_video_widget_get_visuals_list (totem->bvw);
+	list = bacon_video_widget_get_visualization_list (totem->bvw);
 	menu = gtk_menu_new ();
 	gtk_widget_show (menu);
 
-	visual = gconf_client_get_string (totem->gc,
-			GCONF_PREFIX"/visual", NULL);
-	if (visual == NULL || strcmp (visual, "") == 0) {
+	visual = g_settings_get_string (totem->settings, "visualization-name");
+	if (*visual == '\0') {
 		g_free (visual);
 		visual = g_strdup ("goom");
 	}
 
-	item = gtk_builder_get_object (totem->xml, "tpw_visuals_type_combobox");
+	item = gtk_builder_get_object (totem->xml, "tpw_visuals_type_liststore");
 
 	i = 0;
 	for (l = list; l != NULL; l = l->next) {
 		const char *name = l->data;
+		GtkTreeIter iter;
 
-		gtk_combo_box_append_text (GTK_COMBO_BOX (item), name);
+		gtk_list_store_append (GTK_LIST_STORE (item), &iter);
+		gtk_list_store_set (GTK_LIST_STORE (item), &iter,
+				    0, name, -1);
 
-		if (strcmp (name, visual) == 0)
-			gtk_combo_box_set_active (GTK_COMBO_BOX (item), i);
+		if (strcmp (name, visual) == 0) {
+			GObject *combobox;
+
+			combobox = gtk_builder_get_object (totem->xml, "tpw_visuals_type_combobox");
+			gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), i);
+		}
 
 		i++;
 	}
 	g_free (visual);
 
 	/* Visualisation quality */
-	i = gconf_client_get_int (totem->gc,
-			GCONF_PREFIX"/visual_quality", NULL);
-	bacon_video_widget_set_visuals_quality (totem->bvw, i);
 	item = gtk_builder_get_object (totem->xml, "tpw_visuals_size_combobox");
-	gtk_combo_box_set_active (GTK_COMBO_BOX (item), i);
+	g_settings_bind (totem->settings, "visualization-quality", bvw, "visualization-quality", G_SETTINGS_BIND_DEFAULT);
+	g_settings_bind_with_mapping (totem->settings, "visualization-quality", item, "active", G_SETTINGS_BIND_DEFAULT,
+	                              (GSettingsBindGetMapping) int_enum_get_mapping, (GSettingsBindSetMapping) int_enum_set_mapping,
+	                              g_type_class_ref (BVW_TYPE_VISUALIZATION_QUALITY), (GDestroyNotify) g_type_class_unref);
 
 	/* Brightness and all */
 	hidden = 0;
@@ -723,35 +514,21 @@ totem_setup_preferences (Totem *totem)
 	item = gtk_builder_get_object (totem->xml, "font_sel_button");
 	gtk_font_button_set_title (GTK_FONT_BUTTON (item),
 				   _("Select Subtitle Font"));
-	font = gconf_client_get_string (totem->gc,
-		GCONF_PREFIX"/subtitle_font", NULL);
-	if (font && strcmp (font, "") != 0) {
+	font = g_settings_get_string (totem->settings, "subtitle-font");
+	if (*font != '\0') {
 		gtk_font_button_set_font_name (GTK_FONT_BUTTON (item), font);
 		bacon_video_widget_set_subtitle_font (totem->bvw, font);
 	}
 	g_free (font);
-	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/subtitle_font",
-			(GConfClientNotifyFunc) font_changed_cb,
-			totem, NULL, NULL);
+	g_signal_connect (totem->settings, "changed::subtitle-font", (GCallback) font_changed_cb, totem);
 
 	/* Subtitle encoding selection */
 	item = gtk_builder_get_object (totem->xml, "subtitle_encoding_combo");
 	totem_subtitle_encoding_init (GTK_COMBO_BOX (item));
-	value = gconf_client_get_without_default (totem->gc,
-			GCONF_PREFIX"/subtitle_encoding", NULL);
+	encoding = g_settings_get_string (totem->settings, "subtitle-encoding");
 	/* Make sure the default is UTF-8 */
-	if (value != NULL) {
-		if (gconf_value_get_string (value) == NULL) {
-			encoding = g_strdup ("UTF-8");
-		} else {
-			encoding = g_strdup (gconf_value_get_string (value));
-			if (encoding[0] == '\0') {
-				g_free (encoding);
-				encoding = g_strdup ("UTF-8");
-			}
-		}
-		gconf_value_free (value);
-	} else {
+	if (*encoding == '\0') {
+		g_free (encoding);
 		encoding = g_strdup ("UTF-8");
 	}
 	totem_subtitle_encoding_set (GTK_COMBO_BOX(item), encoding);
@@ -759,16 +536,13 @@ totem_setup_preferences (Totem *totem)
 		bacon_video_widget_set_subtitle_encoding (totem->bvw, encoding);
 	}
 	g_free (encoding);
-	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/subtitle_encoding",
-			(GConfClientNotifyFunc) encoding_changed_cb,
-			totem, NULL, NULL);
+	g_signal_connect (totem->settings, "changed::subtitle-encoding", (GCallback) encoding_changed_cb, totem);
 
 	/* Disable keyboard shortcuts */
-	totem->disable_kbd_shortcuts = gconf_client_get_bool (totem->gc,
-							      GCONF_PREFIX"/disable_keyboard_shortcuts", NULL);
-	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/disable_keyboard_shortcuts",
-				 (GConfClientNotifyFunc) disable_kbd_shortcuts_changed_cb,
-				 totem, NULL, NULL);
+	totem->disable_kbd_shortcuts = g_settings_get_boolean (totem->settings, "disable-keyboard-shortcuts");
+	g_signal_connect (totem->settings, "changed::disable-keyboard-shortcuts", (GCallback) disable_kbd_shortcuts_changed_cb, totem);
+
+	g_object_unref (bvw);
 }
 
 void
@@ -776,13 +550,12 @@ totem_preferences_visuals_setup (Totem *totem)
 {
 	char *visual;
 
-	visual = gconf_client_get_string (totem->gc,
-			GCONF_PREFIX"/visual", NULL);
-	if (visual == NULL || strcmp (visual, "") == 0) {
+	visual = g_settings_get_string (totem->settings, "visualization-name");
+	if (*visual == '\0') {
 		g_free (visual);
 		visual = g_strdup ("goom");
 	}
 
-	bacon_video_widget_set_visuals (totem->bvw, visual);
+	bacon_video_widget_set_visualization (totem->bvw, visual);
 	g_free (visual);
 }
