@@ -28,12 +28,11 @@
 #ifndef __TOTEM_PRIVATE_H__
 #define __TOTEM_PRIVATE_H__
 
-#include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
 #include <gio/gio.h>
 
 #include "totem-playlist.h"
-#include "bacon-video-widget.h"
+#include "backend/bacon-video-widget.h"
 #include "totem-open-location.h"
 #include "totem-fullscreen.h"
 #include "totem-plugins-engine.h"
@@ -158,8 +157,8 @@ struct _TotemObject {
 	char *mrl;
 	gint64 seek_to;
 	TotemPlaylist *playlist;
-	GConfClient *gc;
-	GApplication *app;
+	GSettings *settings;
+	GtkApplication *app;
 	TotemStates state;
 	TotemOpenLocation *open_location;
 	gboolean remember_position;
